pub type Processor = fn(Arc<Services>, CommandInput) -> ProcessorFuture;Expand description
Prototype of the command processor. This is a callback supplied by the reloadable admin module.
pub type Processor = fn(Arc<Services>, CommandInput) -> ProcessorFuture;Prototype of the command processor. This is a callback supplied by the reloadable admin module.