pub(super) fn attempt_verdict(backoff: &Backoff) -> ShouldAttemptExpand description
Pure backoff verdict from a peer’s latest failure state: attemptable once the delay past the anchor has elapsed.
pub(super) fn attempt_verdict(backoff: &Backoff) -> ShouldAttemptPure backoff verdict from a peer’s latest failure state: attemptable once the delay past the anchor has elapsed.