pub(super) fn classify(bytes: &[u8]) -> ClassificationExpand description
Decodes the classification byte from a peer-status value.
Missing and unrecognized bytes are treated as transient failures for compatibility with old or malformed rows.
pub(super) fn classify(bytes: &[u8]) -> ClassificationDecodes the classification byte from a peer-status value.
Missing and unrecognized bytes are treated as transient failures for compatibility with old or malformed rows.