pub(super) fn fold_streak(
window_secs: u64,
state: Option<Streak>,
bucket: u64,
value: &[u8],
) -> StreakExpand description
Folds one failure row into a server’s running streak.
The newest row supplies the class and anchor while the first row’s bucket is retained as the oldest edge of the streak.