FedAuth

Trait FedAuth 

pub trait FedAuth: AuthScheme {
    // Required method
    fn input(
        origin: OwnedServerName,
        dest: OwnedServerName,
        keypair: &Ed25519KeyPair,
    ) -> <Self as AuthScheme>::Input<'_>;
}
Builds ruma authentication input from the local federation identity.

Implementations bridge each concrete [AuthScheme] to the common origin, destination, and signing-key context available to the service.

Required Methods

fn input( origin: OwnedServerName, dest: OwnedServerName, keypair: &Ed25519KeyPair, ) -> <Self as AuthScheme>::Input<'_>

Constructs the authentication input expected by this scheme.

Schemes that do not authenticate ignore some or all supplied context.

Dyn Compatibility

This trait is not dyn compatible.

In older versions of Rust, dyn compatibility was called "object safety".

Implementations on Foreign Types

Source

impl FedAuth for NoAccessToken

Source

fn input( _: OwnedServerName, _: OwnedServerName, _: &Ed25519KeyPair, ) -> SendAccessToken<'_>

Source

impl FedAuth for NoAuthentication

Source

fn input(_: OwnedServerName, _: OwnedServerName, _: &Ed25519KeyPair)

Source

impl FedAuth for ServerSignatures

Source

fn input( origin: OwnedServerName, dest: OwnedServerName, keypair: &Ed25519KeyPair, ) -> ServerSignaturesInput<'_>

Implementors