pub trait FedPath: PathBuilder {
// Required method
fn input(supported: &SupportedVersions) -> <Self as PathBuilder>::Input<'_>;
}Expand description
Builds ruma path input from the remote server’s supported versions.
Implementations adapt either a single fixed path or a versioned endpoint history to the same federation request path.
Required Methods
Dyn Compatibility
This trait is not dyn compatible.
In older versions of Rust, dyn compatibility was called "object safety".