fn push_unique(ordered: Candidates, server: OwnedServerName) -> CandidatesExpand description
Append a server to the pool only on its first occurrence.
fn push_unique(ordered: Candidates, server: OwnedServerName) -> CandidatesAppend a server to the pool only on its first occurrence.