batch_limit

Function batch_limit 

fn batch_limit(opts: &Opts) -> UInt
Event count requested per batch op, defaulting to the federation default of 10 and saturating an oversized cap to the wire UInt.