pub(crate) struct Data {
mediaid_file: Arc<Map>,
mediaid_pending: Arc<Map>,
mediaid_user: Arc<Map>,
url_previews: Arc<Map>,
}Fields
mediaid_file: Arc<Map>mediaid_pending: Arc<Map>mediaid_user: Arc<Map>url_previews: Arc<Map>Implementations
Sourceimpl Data
impl Data
pub(super) fn new(db: &Arc<Database>) -> Self
pub(super) fn create_file_metadata( &self, mxc: &Mxc<'_>, user: Option<&UserId>, dim: &Dim, content_disposition: Option<&ContentDisposition>, content_type: Option<&str>, ) -> Result<Vec<u8>>
Sourcepub(super) fn insert_pending_mxc(
&self,
mxc: &Mxc<'_>,
user: &UserId,
unused_expires_at: u64,
)
pub(super) fn insert_pending_mxc( &self, mxc: &Mxc<'_>, user: &UserId, unused_expires_at: u64, )
Insert a pending MXC URI into the database
Sourcepub(super) fn remove_pending_mxc(&self, mxc: &Mxc<'_>)
pub(super) fn remove_pending_mxc(&self, mxc: &Mxc<'_>)
Remove a pending MXC URI from the database
Sourcepub(super) async fn count_pending_mxc_for_user(
&self,
user_id: &UserId,
) -> (usize, u64)
pub(super) async fn count_pending_mxc_for_user( &self, user_id: &UserId, ) -> (usize, u64)
Count the number of pending MXC URIs for a specific user
Sourcepub(super) async fn search_pending_mxc(
&self,
mxc: &Mxc<'_>,
) -> Result<(OwnedUserId, u64)>
pub(super) async fn search_pending_mxc( &self, mxc: &Mxc<'_>, ) -> Result<(OwnedUserId, u64)>
Search for a pending MXC URI in the database
pub(super) async fn delete_file_mxc(&self, mxc: &Mxc<'_>)
Sourcepub(super) async fn search_mxc_metadata_prefix(
&self,
mxc: &Mxc<'_>,
) -> Result<Vec<Vec<u8>>>
pub(super) async fn search_mxc_metadata_prefix( &self, mxc: &Mxc<'_>, ) -> Result<Vec<Vec<u8>>>
Searches for all files with the given MXC
pub(super) async fn file_metadata_exists( &self, mxc: &Mxc<'_>, dim: &Dim, ) -> bool
pub(super) async fn search_file_metadata( &self, mxc: &Mxc<'_>, dim: &Dim, ) -> Result<Metadata>
Sourcepub(super) async fn get_all_user_mxcs(
&self,
user_id: &UserId,
) -> Vec<OwnedMxcUri>
pub(super) async fn get_all_user_mxcs( &self, user_id: &UserId, ) -> Vec<OwnedMxcUri>
Gets all the MXCs associated with a user
Sourcepub(crate) async fn get_all_media_keys(&self) -> Vec<Vec<u8>>
pub(crate) async fn get_all_media_keys(&self) -> Vec<Vec<u8>>
Gets all the media keys in our database (this includes all the metadata associated with it such as width, height, content-type, etc)
pub(super) fn remove_url_preview(&self, url: &str) -> Result
pub(super) fn set_url_preview( &self, url: &str, data: &UrlPreviewData, timestamp: Duration, ) -> Result
pub(super) async fn get_url_preview(&self, url: &str) -> Result<UrlPreviewData>