pub struct Dim {
pub width: u32,
pub height: u32,
pub method: Method,
}Expand description
Dimension specification for a thumbnail.
Fields
width: u32height: u32method: MethodImplementations
Sourceimpl Dim
impl Dim
Sourcepub fn from_ruma(
width: UInt,
height: UInt,
method: Option<Method>,
) -> Result<Self>
pub fn from_ruma( width: UInt, height: UInt, method: Option<Method>, ) -> Result<Self>
Instantiate a Dim from Ruma integers with optional method.
Sourcepub fn new(width: u32, height: u32, method: Option<Method>) -> Self
pub fn new(width: u32, height: u32, method: Option<Method>) -> Self
Instantiate a Dim with optional method
pub fn scaled(&self, image: &Self) -> Result<Self>
Sourcepub fn normalized(&self) -> Self
pub fn normalized(&self) -> Self
Returns width, height of the thumbnail and whether it should be cropped. Returns None when the server should send the original file. Ignores the input Method.