enforce_stripped_create

Function enforce_stripped_create 

pub fn enforce_stripped_create(
    verdict: StrippedCreateVerdict,
    v12_room_ids: bool,
    enforce: bool,
) -> bool
Whether a non-Valid verdict warrants rejecting an invite or dropping the event from knock state, given the room version and operator policy.