v12_room_ids

Function v12_room_ids 

pub fn v12_room_ids(room_version: &RoomVersionId) -> bool
Whether the room version derives room ids from the create event hash (MSC4291, room version 12 and above), which changes how a create event binds to its room.