backfill_server_name

Function backfill_server_name 

async fn backfill_server_name(services: &Services) -> Result
Stamp the marker on a database that pre-dates SERVER_NAME_KEY by probing for any user from the configured server. If none, the database belongs to a different server and reuse is refused.