resolve

Function resolve 

async fn resolve(
    map: &Arc<Map>,
    candidates: &[(u64, SmallVec<[u8; 48]>)],
) -> (Vec<u64>, BTreeMap<u64, u64>, Vec<(u64, SmallVec<[u8; 48]>)>, u64)
Dereferences each candidate’s identity to split losers from winners.

The identity a loser’s reverse row names must hold a live forward row, whose value is the winner. A candidate resolving to itself was a concurrent allocation, not a loser.