pub struct Service {
services: Arc<OnceServices>,
pub providers: Arc<Providers>,
pub sessions: Arc<Sessions>,
pub server: Option<Arc<Server>>,
}Fields
services: Arc<OnceServices>providers: Arc<Providers>sessions: Arc<Sessions>server: Option<Arc<Server>>Implementations
Sourceimpl Service
impl Service
Sourcepub async fn delete_user_sessions(&self, user_id: &UserId)
pub async fn delete_user_sessions(&self, user_id: &UserId)
Remove all session state for a user. For debug and developer use only; deleting state can cause registration conflicts and unintended re-registrations.
Sourceimpl Service
impl Service
Sourcepub async fn revoke_user_tokens(&self, user_id: &UserId)
pub async fn revoke_user_tokens(&self, user_id: &UserId)
Revoke all session tokens for a user.
Sourceimpl Service
impl Service
Sourcepub async fn revoke_token(&self, __arg1: (&Provider, &Session)) -> Result
pub async fn revoke_token(&self, __arg1: (&Provider, &Session)) -> Result
Network request to a Provider revoking a Session’s token.
Sourceimpl Service
impl Service
Sourcepub async fn request_token(
&self,
__arg1: (&Provider, &Session),
code: &str,
) -> Result<TokenResponse>
pub async fn request_token( &self, __arg1: (&Provider, &Session), code: &str, ) -> Result<TokenResponse>
Network request to a Provider to obtain an access token for a Session using a provided code.
Sourceimpl Service
impl Service
Sourcepub async fn request<Body>(
&self,
__arg1: (Option<&Provider>, Option<&Session>),
method: Method,
url: Url,
body: Option<Body>,
) -> Result<JsonValue>where
Body: Serialize,
pub async fn request<Body>(
&self,
__arg1: (Option<&Provider>, Option<&Session>),
method: Method,
url: Url,
body: Option<Body>,
) -> Result<JsonValue>where
Body: Serialize,
Send a request to a provider; this is somewhat abstract since URL’s are
formed prior to this call and could point at anything, however this function
uses the oauth-specific http client and is configured for JSON with special
casing for an error property in the response.