pub struct Service {
timer_channel: (Sender<(OwnedUserId, Duration, u64)>, Receiver<(OwnedUserId, Duration, u64)>),
timeout_remote_users: bool,
idle_timeout: u64,
offline_timeout: u64,
db: Data,
services: Arc<OnceServices>,
last_sync_seen: RwLock<HashMap<OwnedUserId, u64>>,
device_presence: PresenceAggregator,
}Fields
timer_channel: (Sender<(OwnedUserId, Duration, u64)>, Receiver<(OwnedUserId, Duration, u64)>)timeout_remote_users: boolidle_timeout: u64offline_timeout: u64db: Dataservices: Arc<OnceServices>last_sync_seen: RwLock<HashMap<OwnedUserId, u64>>device_presence: PresenceAggregatorImplementations
Sourceimpl Service
impl Service
fn device_key(device_id: Option<&DeviceId>, is_remote: bool) -> DeviceKey
fn schedule_presence_timer( &self, user_id: &UserId, presence_state: &PresenceState, count: u64, ) -> Result
fn refresh_skip_decision( refresh_window_ms: Option<u64>, last_event: Option<&PresenceEvent>, last_count: Option<u64>, ) -> Option<(u64, u64)>
fn timer_is_stale(expected_count: u64, current_count: u64) -> bool
async fn apply_device_presence_update( &self, user_id: &UserId, device_key: DeviceKey, state: &PresenceState, currently_active: Option<bool>, last_active_ago: Option<UInt>, status_msg: StatusMsg, refresh_window_ms: Option<u64>, ) -> Result
Sourcepub async fn maybe_ping_presence(
&self,
user_id: &UserId,
device_id: Option<&DeviceId>,
client_ip: Option<IpAddr>,
new_state: &PresenceState,
) -> Result
pub async fn maybe_ping_presence( &self, user_id: &UserId, device_id: Option<&DeviceId>, client_ip: Option<IpAddr>, new_state: &PresenceState, ) -> Result
Pings the presence of the given user, setting the specified state. When device_id is supplied.
Sourcepub async fn set_presence_for_device(
&self,
user_id: &UserId,
device_id: Option<&DeviceId>,
state: &PresenceState,
status_msg: Option<String>,
) -> Result
pub async fn set_presence_for_device( &self, user_id: &UserId, device_id: Option<&DeviceId>, state: &PresenceState, status_msg: Option<String>, ) -> Result
Applies an explicit presence update for a local device.
Sourcepub async fn set_presence_from_federation(
&self,
user_id: &UserId,
state: &PresenceState,
currently_active: bool,
last_active_ago: UInt,
status_msg: Option<String>,
) -> Result
pub async fn set_presence_from_federation( &self, user_id: &UserId, state: &PresenceState, currently_active: bool, last_active_ago: UInt, status_msg: Option<String>, ) -> Result
Applies a presence update received over federation.
Sourcepub async fn set_presence(
&self,
user_id: &UserId,
state: &PresenceState,
currently_active: Option<bool>,
last_active_ago: Option<UInt>,
status_msg: Option<String>,
) -> Result
pub async fn set_presence( &self, user_id: &UserId, state: &PresenceState, currently_active: Option<bool>, last_active_ago: Option<UInt>, status_msg: Option<String>, ) -> Result
Adds a presence event which will be saved until a new event replaces it.
pub(super) async fn process_presence_timer( &self, user_id: &OwnedUserId, expected_count: u64, ) -> Result
Sourceimpl Service
impl Service
Sourcepub async fn note_sync(&self, user_id: &UserId)
pub async fn note_sync(&self, user_id: &UserId)
record that a user has just successfully completed a /sync (or equivalent activity)
Sourcepub async fn last_sync_gap_ms(&self, user_id: &UserId) -> Option<u64>
pub async fn last_sync_gap_ms(&self, user_id: &UserId) -> Option<u64>
Returns milliseconds since last observed sync for user (if any)
Sourcepub async fn get_presence(&self, user_id: &UserId) -> Result<PresenceEvent>
pub async fn get_presence(&self, user_id: &UserId) -> Result<PresenceEvent>
Returns the latest presence event for the given user.
Sourcepub async fn remove_presence(&self, user_id: &UserId)
pub async fn remove_presence(&self, user_id: &UserId)
Removes the presence record for the given user from the database.
TODO: Why is this not used?
async fn unset_all_presence(&self)
Sourcepub fn presence_since(
&self,
since: u64,
to: Option<u64>,
) -> impl Stream<Item = (&UserId, u64, &[u8])> + Send + '_
pub fn presence_since( &self, since: u64, to: Option<u64>, ) -> impl Stream<Item = (&UserId, u64, &[u8])> + Send + '_
Returns the most recent presence updates that happened after the event
with id since.
pub async fn from_json_bytes_to_event( &self, bytes: &[u8], user_id: &UserId, ) -> Result<PresenceEvent>