room_passes

Function room_passes 

pub(super) fn room_passes<'a, S>(
    rows: S,
    room_id: &'a RoomId,
) -> impl Stream<Item = PrevWalkPass> + Send + 'a
where S: Stream<Item = ((&'a RoomId, u64, &'a EventId), (u8, u64, u64, u8, u64, u64, &'a str))> + Send + 'a,
Take the leading rows of one room from a stream of rows, as passes.

The stream ends at the first row of another room without reading past it.