fn diverging<'a>(
a: &'a HashMap<ShortStateKey, OwnedEventId>,
b: &'a HashMap<ShortStateKey, OwnedEventId>,
) -> impl Iterator<Item = ShortStateKey> + 'aExpand description
Keys of entries in a absent from or differing in b.
fn diverging<'a>(
a: &'a HashMap<ShortStateKey, OwnedEventId>,
b: &'a HashMap<ShortStateKey, OwnedEventId>,
) -> impl Iterator<Item = ShortStateKey> + 'aKeys of entries in a absent from or differing in b.