Service

Struct Service 

pub struct Service {
    services: Arc<OnceServices>,
    db: Db,
}

Fields

services: Arc<OnceServices>db: Db

Implementations

Source

impl Service

pub fn cache_evict(&self, room_id: &RoomId)

Remove the entry for room_id from the cache.

Source

impl Service

pub(super) fn cache_put( &self, room_id: &RoomId, summary: Option<&ParentSummary>, )

Source

impl Service

pub(super) async fn cache_get(&self, room_id: &RoomId) -> Result<Cached>

Source

impl Service

Source

impl Service

pub(super) async fn get_summary_and_children_federation( &self, current_room: &RoomId, sender: &Identifier<'_>, via: &[OwnedServerName], ) -> Result<Accessibility>

Gets the summary of a space using solely federation.

Source

impl Service

pub(super) async fn get_summary_and_children_local( &self, current_room: &RoomId, sender: &Identifier<'_>, ) -> Result<Accessibility>

Gets the summary of a space using solely local information.

Source

impl Service

pub(super) async fn get_room_summary( &self, room_id: &RoomId, children_state: Vec<Raw<HierarchySpaceChildEvent>>, sender: &Identifier<'_>, ) -> Result<Accessibility, Error>

Source

impl Service

pub async fn get_summary_and_children( &self, room_id: &RoomId, sender: &Identifier<'_>, via: &[OwnedServerName], ) -> Result<Accessibility>

Gets the summary of a space using either local or remote (federation) sources

Source

impl Service

pub fn get_space_children<'a>( &'a self, room_id: &'a RoomId, ) -> impl Stream<Item = OwnedRoomId> + Send + 'a

Simply returns the stripped m.space.child events of a room

Source

impl Service

fn get_space_child_events<'a>( &'a self, room_id: &'a RoomId, ) -> impl Stream<Item = impl Event> + Send + 'a

Simply returns the stripped m.space.child events of a room

Source

impl Service

async fn is_accessible_child( &self, current_room: &RoomId, join_rule: &JoinRuleSummary, sender: &Identifier<'_>, ) -> bool

With the given identifier, checks if a room is accessible