select

Function select 

fn select<Id>(
    candidates: Vec<Candidate<Id>>,
    goal: usize,
) -> (Vec<Id>, PruneSummary)
Chooses survivors from the classified leaves. Dangling and referenced leaves are dropped for free (not counted toward goal), own leaves are always kept, and the most-droppable live leaves are dropped up to goal, subject to the one-survivor floor.