pub struct RoomPowerLevelsEvent<E: Event>(E);Expand description
A helper type for an Event of type m.room.power_levels.
Tuple Fields
0: EImplementations
Sourceimpl<E: Event> RoomPowerLevelsEvent<E>
impl<E: Event> RoomPowerLevelsEvent<E>
Sourcefn deserialized_content(&self) -> Result<JsonObject>
fn deserialized_content(&self) -> Result<JsonObject>
The deserialized content of the event.
Sourcepub(crate) fn get_as_int(
&self,
field: RoomPowerLevelsIntField,
rules: &AuthorizationRules,
) -> Result<Option<Int>>
pub(crate) fn get_as_int( &self, field: RoomPowerLevelsIntField, rules: &AuthorizationRules, ) -> Result<Option<Int>>
Get the value of a field that should contain an integer, if any.
The deserialization of this field is cached in memory.
Sourcepub(crate) fn get_as_int_or_default(
&self,
field: RoomPowerLevelsIntField,
rules: &AuthorizationRules,
) -> Result<Int>
pub(crate) fn get_as_int_or_default( &self, field: RoomPowerLevelsIntField, rules: &AuthorizationRules, ) -> Result<Int>
Get the value of a field that should contain an integer, or its default value if it is absent.
Sourcefn get_as_int_map<T: Ord + DeserializeOwned>(
&self,
field: &str,
rules: &AuthorizationRules,
) -> Result<Option<Vec<(T, Int)>>>
fn get_as_int_map<T: Ord + DeserializeOwned>( &self, field: &str, rules: &AuthorizationRules, ) -> Result<Option<Vec<(T, Int)>>>
Get the value of a field that should contain a map of any value to integer, if any.
Sourcepub(crate) fn events(
&self,
rules: &AuthorizationRules,
) -> Result<Option<Vec<(TimelineEventType, Int)>>>
pub(crate) fn events( &self, rules: &AuthorizationRules, ) -> Result<Option<Vec<(TimelineEventType, Int)>>>
Get the power levels required to send events, if any.
Sourcepub(crate) fn notifications(
&self,
rules: &AuthorizationRules,
) -> Result<Option<Vec<(String, Int)>>>
pub(crate) fn notifications( &self, rules: &AuthorizationRules, ) -> Result<Option<Vec<(String, Int)>>>
Get the power levels required to trigger notifications, if any.
Sourcepub(crate) fn users(
&self,
rules: &AuthorizationRules,
) -> Result<Option<Vec<(OwnedUserId, Int)>>>
pub(crate) fn users( &self, rules: &AuthorizationRules, ) -> Result<Option<Vec<(OwnedUserId, Int)>>>
Get the power levels of the users, if any.
The deserialization of this field is cached in memory.
Sourcepub(crate) fn user_power_level(
&self,
user_id: &UserId,
rules: &AuthorizationRules,
) -> Result<UserPowerLevel>
pub(crate) fn user_power_level( &self, user_id: &UserId, rules: &AuthorizationRules, ) -> Result<UserPowerLevel>
Get the power level of the user with the given ID.
Calling this method several times should be cheap because the necessary deserialization results are cached.
Sourcepub(crate) fn event_power_level(
&self,
event_type: &TimelineEventType,
state_key: Option<&str>,
rules: &AuthorizationRules,
) -> Result<Int>
pub(crate) fn event_power_level( &self, event_type: &TimelineEventType, state_key: Option<&str>, rules: &AuthorizationRules, ) -> Result<Int>
Get the power level required to send an event of the given type.
Sourcepub(crate) fn int_fields_map(
&self,
rules: &AuthorizationRules,
) -> Result<Vec<(RoomPowerLevelsIntField, Int)>>
pub(crate) fn int_fields_map( &self, rules: &AuthorizationRules, ) -> Result<Vec<(RoomPowerLevelsIntField, Int)>>
Get a map of all the fields with an integer value in the content of an
m.room.power_levels event.