pub(super) struct PowerEvent(pub(super) bool);Expand description
Whether a stored event is a power event, decoded from the fields that decide it.
Definition in the spec:
A power event is a state event with type
m.room.power_levelsorm.room.join_rules, or a state event with typem.room.memberwhere themembershipisleaveorbanand thesenderdoes not match thestate_key. The idea behind this is that power events are events that might remove someone’s ability to do something in the room.
m.room.create is included, extending the spec definition to match Synapse
and Ruma.
Tuple Fields
0: boolTrait Implementations
Sourceimpl<'de> Deserialize<'de> for PowerEvent
impl<'de> Deserialize<'de> for PowerEvent
Sourcefn deserialize<D>(deserializer: D) -> Result<Self, D::Error>where
D: Deserializer<'de>,
fn deserialize<D>(deserializer: D) -> Result<Self, D::Error>where
D: Deserializer<'de>,