auth_check

Function auth_check 

pub async fn auth_check<Fetch, State>(
    rules: &RoomVersionRules,
    incoming_event: &PduEvent,
    fetch_event: Fetch,
    fetch_state: State,
) -> Result<AuthCheckOutcome>
where Fetch: FetchEvent, State: FetchState,
Checks an event against its state-independent and state-dependent rules.

A completed check returns an explicit allowance or denial. Failures to obtain or evaluate the required authorization inputs remain errors.