INITIAL_EVENTS

Function INITIAL_EVENTS 

pub fn INITIAL_EVENTS() -> HashMap<OwnedEventId, PduEvent>
Builds the common room state and membership fixture events.

Events are indexed by identifier for use in resolution fixtures.