RoomMutexGuard

Type Alias RoomMutexGuard 

pub type RoomMutexGuard = MutexMapGuard<OwnedRoomId, ()>;
Guard proving exclusive access to a room’s timeline insertion path.

Acquire it after any federation or state guard held for the same room, and never acquire either outer guard while retaining it.

Aliased Type

pub struct RoomMutexGuard { /* private fields */ }