Enum GetResultPayload
pub enum GetResultPayload {
File(File, PathBuf),
Stream(Pin<Box<dyn Stream<Item = Result<Bytes, Error>> + Send>>),
}Expand description
The kind of a GetResult
This special cases the case of a local file, as some systems may be able to optimise the case of a file already present on local disk
Variants
File(File, PathBuf)
The file, path
Stream(Pin<Box<dyn Stream<Item = Result<Bytes, Error>> + Send>>)
An opaque stream of bytes