chunked

Function chunked 

fn chunked(
    payload: PutPayload,
    part_size: usize,
) -> impl Iterator<Item = PutPayload>
Splits a payload into nonempty parts no larger than part_size.

The iterator owns the payload buffer and advances it without copying the bytes in each yielded part.