Struct GetResult
pub struct GetResult {
pub payload: GetResultPayload,
pub meta: ObjectMeta,
pub range: Range<u64>,
pub attributes: Attributes,
}Expand description
Result for a get request
Fields
payload: GetResultPayloadThe GetResultPayload
meta: ObjectMetaThe [ObjectMeta] for this object
range: Range<u64>The range of bytes returned by this request
Note this is not usize as object_store supports 32-bit architectures such as WASM
attributes: AttributesAdditional object attributes
Implementations
impl GetResult
impl GetResult
pub fn into_stream(
self,
) -> Pin<Box<dyn Stream<Item = Result<Bytes, Error>> + Send>>
pub fn into_stream( self, ) -> Pin<Box<dyn Stream<Item = Result<Bytes, Error>> + Send>>
Converts this into a byte stream
If the self.kind is GetResultPayload::File will perform chunked reads of the file,
otherwise will return the GetResultPayload::Stream.
Tokio Compatibility
Tokio discourages performing blocking IO on a tokio worker thread, however,
no major operating systems have stable async file APIs. Therefore if called from
a tokio context, this will use [tokio::runtime::Handle::spawn_blocking] to dispatch
IO to a blocking thread pool, much like tokio::fs does under-the-hood.
If not called from a tokio context, this will perform IO on the current thread with no additional complexity or overheads