pub async fn create_admin_room(services: &Services) -> Result
Create the admin room.
Users in this room are considered admins by tuwunel, and the room can be used to issue admin commands by talking to the server user inside it.