pub type CommandOutput = RoomMessageEventContent;Expand description
Alias for the output structure.
Aliased Type
pub struct CommandOutput {
pub msgtype: MessageType,
pub relates_to: Option<Relation<RoomMessageEventContentWithoutRelation>>,
pub mentions: Option<Mentions>,
}Fields
msgtype: MessageTypeA key which identifies the type of message being sent.
This also holds the specific content of each message.
relates_to: Option<Relation<RoomMessageEventContentWithoutRelation>>Information about related messages.
mentions: Option<Mentions>The mentions of this event.
This should always be set to avoid triggering the legacy mention push rules. It is
recommended to modify this field only before calling a method that adds a relation. For
example, make_replacement() needs to know all the mentions
beforehand to avoid re-triggering notifications for users that were already mentioned in
the original event.