pub type ProcessorResult = Result<Option<CommandOutput>, Box<CommandOutput>>;Expand description
Result wrapping of a command’s handling. Both variants are complete message events which have digested any prior errors. The wrapping preserves whether the command failed without interpreting the text. Ok(None) outputs are dropped to produce no response.
Aliased Type
pub enum ProcessorResult {
Ok(Option<RoomMessageEventContent>),
Err(Box<RoomMessageEventContent>),
}