async fn worker(
service: Arc<dyn Service>,
mgr: Arc<Manager>,
) -> (Arc<dyn Service>, Result)Expand description
Base frame for service worker. This runs in a tokio::task. All errors and panics from the worker are caught and returned cleanly. The JoinHandle should never error with a panic, and if so it should propagate, but it may error with an Abort which the manager should handle along with results to determine if the worker should be restarted.