pub(crate) async fn checkup_sha256_media(services: &Services) -> ResultExpand description
Check is run on startup for prior-migrated media directories. This handles:
- Going back and forth to non-sha256 legacy binaries (e.g. upstream).
- Deletion of artifacts in the media directory which will then fall out of sync with the database.