pub struct Service {
pub(crate) db: Data,
services: Arc<OnceServices>,
url_preview_mutex: MutexMap<String, ()>,
federation_mutex: MutexMap<String, ()>,
mxc_state: MXCState,
}Fields
db: Dataservices: Arc<OnceServices>url_preview_mutex: MutexMap<String, ()>federation_mutex: MutexMap<String, ()>mxc_state: MXCStateImplementations
Sourceimpl Service
impl Service
pub fn set_url_preview(&self, url: &str, data: &UrlPreviewData) -> Result
Sourceimpl Service
impl Service
pub async fn get_url_preview(&self, url: &Url) -> Result<UrlPreviewData>
Sourceimpl Service
impl Service
async fn request_url_preview(&self, url: &Url) -> Result<UrlPreviewData>
Sourceimpl Service
impl Service
pub async fn download_image(&self, response: Response) -> Result<UrlPreviewData>
Sourceimpl Service
impl Service
async fn download_html( &self, url: &Url, response: Response, ) -> Result<UrlPreviewData>
Sourceimpl Service
impl Service
async fn handle_thumbnail_file( &self, mxc: &Mxc<'_>, dim: &Dim, content: Content, ) -> Result<Media>
Sourceimpl Service
impl Service
async fn handle_content_file( &self, mxc: &Mxc<'_>, content: Content, ) -> Result<Media>
Sourceimpl Service
impl Service
async fn handle_location(&self, mxc: &Mxc<'_>, location: &str) -> Result<Media>
Sourceimpl Service
impl Service
pub async fn fetch_remote_thumbnail_legacy( &self, body: &Request, ) -> Result<Response>
Sourceimpl Service
impl Service
Sourcepub async fn upload_thumbnail(
&self,
mxc: &Mxc<'_>,
content_disposition: Option<&ContentDisposition>,
content_type: Option<&str>,
dim: &Dim,
file: &[u8],
) -> Result
pub async fn upload_thumbnail( &self, mxc: &Mxc<'_>, content_disposition: Option<&ContentDisposition>, content_type: Option<&str>, dim: &Dim, file: &[u8], ) -> Result
Uploads or replaces a file thumbnail.
pub async fn get_or_fetch_thumbnail( &self, mxc: &Mxc<'_>, dim: &Dim, timeout_ms: Duration, user: &UserId, ) -> Result<Media>
Sourcepub async fn get_thumbnail(
&self,
mxc: &Mxc<'_>,
dim: &Dim,
timeout_duration: Option<Duration>,
) -> Result<Media>
pub async fn get_thumbnail( &self, mxc: &Mxc<'_>, dim: &Dim, timeout_duration: Option<Duration>, ) -> Result<Media>
Download a thumbnail and wait up to a timeout_ms if it is pending.
Sourcepub async fn get_stored_thumbnail(
&self,
mxc: &Mxc<'_>,
dim: &Dim,
) -> Result<Media>
pub async fn get_stored_thumbnail( &self, mxc: &Mxc<'_>, dim: &Dim, ) -> Result<Media>
Downloads a file’s thumbnail.
Here’s an example on how it works:
- Client requests an image with width=567, height=567
- Server rounds that up to (800, 600), so it doesn’t have to save too many thumbnails
- Server rounds that up again to (958, 600) to fix the aspect ratio (only for width,height>96)
- Server creates the thumbnail and sends it to the user
For width,height <= 96 the server uses another thumbnailing algorithm which crops the image afterwards.
Sourceimpl Service
impl Service
Sourceasync fn get_thumbnail_saved(&self, data: Metadata) -> Result<Media>
async fn get_thumbnail_saved(&self, data: Metadata) -> Result<Media>
Using saved thumbnail
Sourceimpl Service
impl Service
Sourcepub async fn create_pending(
&self,
mxc: &Mxc<'_>,
user: &UserId,
unused_expires_at: u64,
) -> Result
pub async fn create_pending( &self, mxc: &Mxc<'_>, user: &UserId, unused_expires_at: u64, ) -> Result
Create a pending media upload ID.
Sourcepub async fn upload_pending(
&self,
mxc: &Mxc<'_>,
user: &UserId,
content_disposition: Option<&ContentDisposition>,
content_type: Option<&str>,
file: &[u8],
) -> Result
pub async fn upload_pending( &self, mxc: &Mxc<'_>, user: &UserId, content_disposition: Option<&ContentDisposition>, content_type: Option<&str>, file: &[u8], ) -> Result
Uploads content to a pending media ID.
Sourcepub async fn create(
&self,
mxc: &Mxc<'_>,
user: Option<&UserId>,
content_disposition: Option<&ContentDisposition>,
content_type: Option<&str>,
file: &[u8],
) -> Result
pub async fn create( &self, mxc: &Mxc<'_>, user: Option<&UserId>, content_disposition: Option<&ContentDisposition>, content_type: Option<&str>, file: &[u8], ) -> Result
Uploads a file.
Sourcepub async fn delete(&self, mxc: &Mxc<'_>) -> Result
pub async fn delete(&self, mxc: &Mxc<'_>) -> Result
Deletes a file in the database and from the media directory via an MXC
Sourcepub async fn delete_from_user(&self, user: &UserId) -> Result<usize>
pub async fn delete_from_user(&self, user: &UserId) -> Result<usize>
Deletes all media by the specified user
currently, this is only practical for local users
Sourcepub async fn get_or_fetch(
&self,
mxc: &Mxc<'_>,
timeout_ms: Duration,
) -> Result<Media>
pub async fn get_or_fetch( &self, mxc: &Mxc<'_>, timeout_ms: Duration, ) -> Result<Media>
Get file from local storage or make a federation request if it originates remotely.
Sourcepub async fn get(
&self,
mxc: &Mxc<'_>,
timeout: Option<Duration>,
) -> Result<Media>
pub async fn get( &self, mxc: &Mxc<'_>, timeout: Option<Duration>, ) -> Result<Media>
Get file from local storage while waiting up to a timeout_ms if it is pending.
Sourcepub async fn get_stored(&self, mxc: &Mxc<'_>) -> Result<Media>
pub async fn get_stored(&self, mxc: &Mxc<'_>) -> Result<Media>
Get file from local storage.
Sourcepub async fn get_all_mxcs(&self) -> Result<Vec<OwnedMxcUri>>
pub async fn get_all_mxcs(&self) -> Result<Vec<OwnedMxcUri>>
Gets all the MXC URIs in our media database
Sourcepub async fn delete_range(
&self,
time: SystemTime,
older_than: bool,
newer_than: bool,
yes_i_want_to_delete_local_media: bool,
) -> Result<usize>
pub async fn delete_range( &self, time: SystemTime, older_than: bool, newer_than: bool, yes_i_want_to_delete_local_media: bool, ) -> Result<usize>
Deletes all media files before or after the given time. Returns a usize with the number of media files deleted.
pub async fn create_media_dir(&self) -> Result
async fn remove_media_file(&self, key: &[u8]) -> Result
async fn create_media_file(&self, key: &[u8], file: &[u8]) -> Result
fn storage_providers(&self) -> impl Iterator<Item = &Arc<Provider>> + Send + '_
pub async fn get_metadata(&self, mxc: &Mxc<'_>) -> Option<Metadata>
pub fn get_media_path_sha256(&self, key: &[u8]) -> PathBuf
Sourcepub fn get_media_name_sha256(&self, key: &[u8]) -> String
pub fn get_media_name_sha256(&self, key: &[u8]) -> String
new SHA256 file name media function. requires database migrated. uses SHA256 hash of the base64 key as the file name
Sourcepub fn get_media_path_b64(&self, key: &[u8]) -> PathBuf
pub fn get_media_path_b64(&self, key: &[u8]) -> PathBuf
old base64 file name media function
This is the old version of get_media_path_sha256 that uses the full
base64 key as the filename.
pub fn get_media_dir(&self) -> PathBuf