pub struct Providers {
services: Arc<OnceServices>,
providers: RwLock<BTreeMap<ProviderId, Provider>>,
}Expand description
Discovered providers
Fields
services: Arc<OnceServices>providers: RwLock<BTreeMap<ProviderId, Provider>>Implementations
Sourceimpl Providers
impl Providers
Sourcepub fn get_config(&self, id: &str) -> Result<Provider>
pub fn get_config(&self, id: &str) -> Result<Provider>
Get the admin-configured Provider which exists prior to any reconciliation with the well-known discovery (the server’s config is immutable); though it is important to note the server config can be reloaded. This will Err NotFound for a non-existent idp.
When no provider is found with a matching client_id, providers are then searched by brand. Brand matching will be invalidated when more than one provider matches the brand.
Sourceimpl Providers
impl Providers
Sourcepub fn get_default_id(&self) -> Option<String>
pub fn get_default_id(&self) -> Option<String>
Get the ID of the provider considered “default” as selected by the admin or by fallback.
Sourceimpl Providers
impl Providers
Sourceasync fn get_cached(&self, id: &str) -> Option<Provider>
async fn get_cached(&self, id: &str) -> Option<Provider>
Get the discovered provider from the runtime cache. ID may be client_id or brand if brand is unique among provider configurations.
Sourceimpl Providers
impl Providers
Sourceasync fn configure(&self, provider: Provider) -> Result<Provider>
async fn configure(&self, provider: Provider) -> Result<Provider>
Configure an identity provider; takes the admin-configured instance from the server’s config, queries the provider for discovery, and then returns an updated config based on the proper reconciliation. This final config is then cached in memory to avoid repeating this process.