pub struct Server {
services: Arc<OnceServices>,
db: Data,
jwk: Value,
key: SigningKey,
device_locks: MutexMap<String, ()>,
}Fields
services: Arc<OnceServices>db: Datajwk: Valuekey: SigningKeydevice_locks: MutexMap<String, ()>Serializes the read-check-consume of a device grant by its device_code
so concurrent polls of one approved grant cannot each mint a device.
Implementations
Sourceimpl Server
impl Server
pub fn create_auth_code( &self, auth_req: &AuthRequest, user_id: OwnedUserId, ) -> String
Sourceimpl Server
impl Server
pub fn store_auth_request(&self, req_id: &str, request: &AuthRequest)
Sourceimpl Server
impl Server
pub async fn take_auth_request(&self, req_id: &str) -> Result<AuthRequest>
Sourceimpl Server
impl Server
pub async fn exchange_auth_code( &self, code: &str, client_id: &str, redirect_uri: &str, code_verifier: Option<&str>, require_pkce: bool, ) -> Result<AuthCodeSession>
Sourceimpl Server
impl Server
pub async fn register_client( &self, request: DcrRequest, ) -> Result<ClientRegistration>
Sourceimpl Server
impl Server
pub async fn get_client(&self, client_id: &str) -> Result<ClientRegistration>
Sourceimpl Server
impl Server
pub fn create_device_grant(&self, client_id: &str, scope: &str) -> DeviceGrant
Sourceimpl Server
impl Server
Sourceasync fn resolve_device_code(&self, user_code: &str) -> Result<String>
async fn resolve_device_code(&self, user_code: &str) -> Result<String>
Resolve a user-entered (possibly hyphenated, lower-case) code to its stored
device_code via the index.
Sourceimpl Server
impl Server
Sourcepub async fn verify_device_grant(&self, user_code: &str) -> Result<DeviceGrant>
pub async fn verify_device_grant(&self, user_code: &str) -> Result<DeviceGrant>
Look up a pending grant for the browser consent step, counting the attempt
and self-invalidating the grant past MAX_VERIFY_ATTEMPTS (RFC 8628 5.1).
Sourceimpl Server
impl Server
Sourcepub async fn poll_device_grant(
&self,
device_code: &str,
client_id: &str,
) -> Result<DeviceGrantPoll>
pub async fn poll_device_grant( &self, device_code: &str, client_id: &str, ) -> Result<DeviceGrantPoll>
Poll a device grant by its device_code (RFC 8628 3.4). A terminal outcome
consumes the grant; a pending grant is left in place for the next poll.
Sourceimpl Server
impl Server
async fn get_device_grant(&self, device_code: &str) -> Result<DeviceGrant>
Sourceimpl Server
impl Server
async fn set_device_grant_status( &self, user_code: &str, status: DeviceGrantStatus, ) -> Result
Sourceimpl Server
impl Server
pub fn sign_id_token(&self, claims: &IdTokenClaims) -> Result<String>