pub struct Session {Show 17 fields
pub idp_id: Option<String>,
pub sess_id: Option<SessionId>,
pub token_type: Option<String>,
pub access_token: Option<String>,
pub expires_in: Option<u64>,
pub expires_at: Option<SystemTime>,
pub refresh_token: Option<String>,
pub refresh_token_expires_in: Option<u64>,
pub refresh_token_expires_at: Option<SystemTime>,
pub scope: Option<String>,
pub redirect_url: Option<Url>,
pub code_verifier: Option<String>,
pub cookie_nonce: Option<String>,
pub query_nonce: Option<String>,
pub authorize_expires_at: Option<SystemTime>,
pub user_id: Option<OwnedUserId>,
pub user_info: Option<UserInfo>,
}Expand description
Session ultimately represents an OAuth authorization session yielding an associated matrix user registration. Maintains the state between authorization steps and the association to the matrix user until deactivation or revocation.
Fields
idp_id: Option<String>Identity Provider ID (the client_id in the configuration) associated
with this session.
sess_id: Option<SessionId>Session ID used as the index key for this session itself.
token_type: Option<String>Token type (bearer, mac, etc).
access_token: Option<String>Access token to the provider.
expires_in: Option<u64>Duration in seconds the access_token is valid for.
expires_at: Option<SystemTime>Point in time that the access_token expires.
refresh_token: Option<String>Token used to refresh the access_token.
refresh_token_expires_in: Option<u64>Duration in seconds the refresh_token is valid for
refresh_token_expires_at: Option<SystemTime>Point in time that the refresh_token expires.
scope: Option<String>Access scope actually granted (if supported).
redirect_url: Option<Url>Redirect URL
code_verifier: Option<String>Challenge preimage
Random string passed exclusively in the grant session cookie.
query_nonce: Option<String>Random single-use string passed in the provider redirect.
Point in time the authorization grant session expires.
user_id: Option<OwnedUserId>Associated User Id registration.
user_info: Option<UserInfo>Last userinfo response persisted here.