type ClearedFields = SmallVec<[ProfileFieldName; 2]>;Expand description
The field names a profile holds when it is cleared.
A profile commonly holds only the two canonical fields, which sizes the inline budget.
Aliased Type
struct ClearedFields { /* private fields */ }