pub struct Service {
db: Data,
services: Arc<OnceServices>,
}Fields
db: Dataservices: Arc<OnceServices>Implementations
Sourceimpl Service
impl Service
Sourcepub async fn issue_token(
&self,
expires: TokenExpires,
) -> Result<(String, DatabaseTokenInfo)>
pub async fn issue_token( &self, expires: TokenExpires, ) -> Result<(String, DatabaseTokenInfo)>
Issue a new registration token and save it in the database.
pub async fn is_enabled(&self) -> bool
pub fn get_config_tokens(&self) -> HashSet<String>
pub async fn is_token_valid(&self, token: &str) -> Result
pub async fn try_consume(&self, token: &str) -> Result
async fn check(&self, token: &str, consume: bool) -> Result
Sourcepub async fn revoke_token(&self, token: &str) -> Result
pub async fn revoke_token(&self, token: &str) -> Result
Try to revoke a valid token.
Note that tokens set in the config file cannot be revoked.
Sourcepub fn iterate_tokens(&self) -> impl Stream<Item = ValidToken> + Send + '_
pub fn iterate_tokens(&self) -> impl Stream<Item = ValidToken> + Send + '_
Iterate over all valid registration tokens.