pub(super) fn pass_row<'a>(
upgrade: &PrevUpgrade<'a>,
pass: &Pass,
ended_ms: u64,
) -> ((&'a RoomId, u64, &'a EventId), (u8, u64, u64, u8, u64, u64, &'a str))Expand description
Encode a pass as the row recording it.
The end is given in milliseconds since the Unix epoch: the wall clock when recording, a fixed time in a test.