pub(super) fn room_passes<'a, S>(
rows: S,
room_id: &'a RoomId,
) -> impl Stream<Item = PrevWalkPass> + Send + 'aExpand description
Take the leading rows of one room from a stream of rows, as passes.
The stream ends at the first row of another room without reading past it.