pub struct Service {
services: Arc<OnceServices>,
db: Db,
}Fields
services: Arc<OnceServices>db: DbImplementations
Sourceimpl Service
impl Service
Sourcepub fn cache_evict(&self, room_id: &RoomId)
pub fn cache_evict(&self, room_id: &RoomId)
Remove the entry for room_id from the cache.
Sourceimpl Service
impl Service
fn generate_ttl(&self) -> SystemTime
Sourceimpl Service
impl Service
Sourcepub(super) async fn get_summary_and_children_federation(
&self,
current_room: &RoomId,
sender: &Identifier<'_>,
via: &[OwnedServerName],
) -> Result<Accessibility>
pub(super) async fn get_summary_and_children_federation( &self, current_room: &RoomId, sender: &Identifier<'_>, via: &[OwnedServerName], ) -> Result<Accessibility>
Gets the summary of a space using solely federation.
Sourceimpl Service
impl Service
Sourcepub(super) async fn get_summary_and_children_local(
&self,
current_room: &RoomId,
sender: &Identifier<'_>,
) -> Result<Accessibility>
pub(super) async fn get_summary_and_children_local( &self, current_room: &RoomId, sender: &Identifier<'_>, ) -> Result<Accessibility>
Gets the summary of a space using solely local information.
Sourceimpl Service
impl Service
pub(super) async fn get_room_summary( &self, room_id: &RoomId, children_state: Vec<Raw<HierarchySpaceChildEvent>>, sender: &Identifier<'_>, ) -> Result<Accessibility, Error>
Sourceimpl Service
impl Service
Sourcepub async fn get_summary_and_children(
&self,
room_id: &RoomId,
sender: &Identifier<'_>,
via: &[OwnedServerName],
) -> Result<Accessibility>
pub async fn get_summary_and_children( &self, room_id: &RoomId, sender: &Identifier<'_>, via: &[OwnedServerName], ) -> Result<Accessibility>
Gets the summary of a space using either local or remote (federation) sources
Sourceimpl Service
impl Service
Sourcepub fn get_space_children<'a>(
&'a self,
room_id: &'a RoomId,
) -> impl Stream<Item = OwnedRoomId> + Send + 'a
pub fn get_space_children<'a>( &'a self, room_id: &'a RoomId, ) -> impl Stream<Item = OwnedRoomId> + Send + 'a
Simply returns the stripped m.space.child events of a room
Sourceimpl Service
impl Service
Sourcefn get_space_child_events<'a>(
&'a self,
room_id: &'a RoomId,
) -> impl Stream<Item = impl Event> + Send + 'a
fn get_space_child_events<'a>( &'a self, room_id: &'a RoomId, ) -> impl Stream<Item = impl Event> + Send + 'a
Simply returns the stripped m.space.child events of a room
Sourceimpl Service
impl Service
Sourceasync fn is_accessible_child(
&self,
current_room: &RoomId,
join_rule: &JoinRuleSummary,
sender: &Identifier<'_>,
) -> bool
async fn is_accessible_child( &self, current_room: &RoomId, join_rule: &JoinRuleSummary, sender: &Identifier<'_>, ) -> bool
With the given identifier, checks if a room is accessible