pub struct Service {
pub mutex: MutexMap<OwnedRoomId, ()>,
services: Arc<OnceServices>,
db: Data,
}Fields
mutex: MutexMap<OwnedRoomId, ()>services: Arc<OnceServices>db: DataImplementations
Sourceimpl Service
impl Service
Sourcepub async fn force_state(
&self,
room_id: &RoomId,
shortstatehash: u64,
statediffnew: Arc<CompressedState>,
_statediffremoved: Arc<CompressedState>,
state_lock: &RoomMutexGuard,
) -> Result
pub async fn force_state( &self, room_id: &RoomId, shortstatehash: u64, statediffnew: Arc<CompressedState>, _statediffremoved: Arc<CompressedState>, state_lock: &RoomMutexGuard, ) -> Result
Set the room to the given statehash and update caches.
Sourceimpl Service
impl Service
Sourcepub async fn set_event_state(
&self,
event_id: &EventId,
room_id: &RoomId,
state_ids_compressed: Arc<CompressedState>,
) -> Result<ShortStateHash>
pub async fn set_event_state( &self, event_id: &EventId, room_id: &RoomId, state_ids_compressed: Arc<CompressedState>, ) -> Result<ShortStateHash>
Generates a new StateHash and associates it with the incoming event.
This adds all current state events (not including the incoming event)
to stateid_pduid and adds the incoming event to eventid_statehash.
Sourceimpl Service
impl Service
Sourcepub async fn append_to_state(&self, new_pdu: &PduEvent) -> Result<u64>
pub async fn append_to_state(&self, new_pdu: &PduEvent) -> Result<u64>
Generates a new StateHash and associates it with the incoming event.
This adds all current state events (not including the incoming event)
to stateid_pduid and adds the incoming event to eventid_statehash.
Sourceimpl Service
impl Service
Sourcepub fn set_room_state(
&self,
room_id: &RoomId,
shortstatehash: u64,
_mutex_lock: &RoomMutexGuard,
)
pub fn set_room_state( &self, room_id: &RoomId, shortstatehash: u64, _mutex_lock: &RoomMutexGuard, )
Set the state hash to a new version, but does not update state_cache.
Sourceimpl Service
impl Service
Sourceimpl Service
impl Service
pub async fn summary_stripped<Pdu: Event>( &self, event: &Pdu, ) -> Vec<Raw<AnyStrippedStateEvent>>
Sourceimpl Service
impl Service
Sourcepub async fn get_room_version_rules(
&self,
room_id: &RoomId,
) -> Result<RoomVersionRules>
pub async fn get_room_version_rules( &self, room_id: &RoomId, ) -> Result<RoomVersionRules>
Returns the room’s version rules
Sourceimpl Service
impl Service
Sourcepub async fn get_room_version(&self, room_id: &RoomId) -> Result<RoomVersionId>
pub async fn get_room_version(&self, room_id: &RoomId) -> Result<RoomVersionId>
Returns the room’s version.
Sourceimpl Service
impl Service
pub async fn get_room_shortstatehash( &self, room_id: &RoomId, ) -> Result<ShortStateHash>
Sourceimpl Service
impl Service
Sourcepub async fn pdu_shortstatehash(
&self,
event_id: &EventId,
) -> Result<ShortStateHash>
pub async fn pdu_shortstatehash( &self, event_id: &EventId, ) -> Result<ShortStateHash>
Returns the state hash at this event.
Sourceimpl Service
impl Service
Sourcepub async fn get_shortstatehash(
&self,
shorteventid: ShortEventId,
) -> Result<ShortStateHash>
pub async fn get_shortstatehash( &self, shorteventid: ShortEventId, ) -> Result<ShortStateHash>
Returns the state hash at this event.
Sourceimpl Service
impl Service
pub(super) fn delete_room_shortstatehash( &self, room_id: &RoomId, _mutex_lock: &Guard<OwnedRoomId, ()>, ) -> Result
Sourceimpl Service
impl Service
pub fn get_forward_extremities<'a>( &'a self, room_id: &'a RoomId, ) -> impl Stream<Item = &EventId> + Send + '_
Sourceimpl Service
impl Service
pub async fn set_forward_extremities<'a, I>( &'a self, room_id: &'a RoomId, event_ids: I, _state_lock: &'a RoomMutexGuard, )