pub struct Service {
services: Arc<OnceServices>,
}Fields
services: Arc<OnceServices>Implementations
Sourceimpl Service
impl Service
Sourcepub async fn room_state_get_content<T>(
&self,
room_id: &RoomId,
event_type: &StateEventType,
state_key: &str,
) -> Result<T>where
T: for<'de> Deserialize<'de> + Send,
pub async fn room_state_get_content<T>(
&self,
room_id: &RoomId,
event_type: &StateEventType,
state_key: &str,
) -> Result<T>where
T: for<'de> Deserialize<'de> + Send,
Returns a single PDU from room_id with key (event_type,state_key).
Sourceimpl Service
impl Service
Sourcepub fn room_state_type_pdus<'a>(
&'a self,
room_id: &'a RoomId,
event_type: &'a StateEventType,
) -> impl Stream<Item = Result<impl Event>> + Send + 'a
pub fn room_state_type_pdus<'a>( &'a self, room_id: &'a RoomId, event_type: &'a StateEventType, ) -> impl Stream<Item = Result<impl Event>> + Send + 'a
Returns the room state events for a specific type.
Sourceimpl Service
impl Service
Sourcepub fn room_state_full_pdus<'a>(
&'a self,
room_id: &'a RoomId,
) -> impl Stream<Item = Result<impl Event>> + Send + 'a
pub fn room_state_full_pdus<'a>( &'a self, room_id: &'a RoomId, ) -> impl Stream<Item = Result<impl Event>> + Send + 'a
Returns the full room state pdus
Sourceimpl Service
impl Service
Sourcepub async fn room_state_get_id(
&self,
room_id: &RoomId,
event_type: &StateEventType,
state_key: &str,
) -> Result<OwnedEventId>
pub async fn room_state_get_id( &self, room_id: &RoomId, event_type: &StateEventType, state_key: &str, ) -> Result<OwnedEventId>
Returns a single EventId from room_id with key (event_type,
state_key).
Sourceimpl Service
impl Service
Sourcepub fn room_state_keys_with_ids<'a>(
&'a self,
room_id: &'a RoomId,
event_type: &'a StateEventType,
) -> impl Stream<Item = Result<(StateKey, OwnedEventId)>> + Send + 'a
pub fn room_state_keys_with_ids<'a>( &'a self, room_id: &'a RoomId, event_type: &'a StateEventType, ) -> impl Stream<Item = Result<(StateKey, OwnedEventId)>> + Send + 'a
Iterates the state_keys for an event_type in the state joined by the
event_id from the current state.
Sourceimpl Service
impl Service
Sourcepub fn room_state_keys<'a>(
&'a self,
room_id: &'a RoomId,
event_type: &'a StateEventType,
) -> impl Stream<Item = Result<StateKey>> + Send + 'a
pub fn room_state_keys<'a>( &'a self, room_id: &'a RoomId, event_type: &'a StateEventType, ) -> impl Stream<Item = Result<StateKey>> + Send + 'a
Iterates the state_keys for an event_type in the state
Sourceimpl Service
impl Service
Sourcepub async fn room_state_get(
&self,
room_id: &RoomId,
event_type: &StateEventType,
state_key: &str,
) -> Result<Pdu>
pub async fn room_state_get( &self, room_id: &RoomId, event_type: &StateEventType, state_key: &str, ) -> Result<Pdu>
Returns a single PDU from room_id with key (event_type,
state_key).
Sourceimpl Service
impl Service
Sourcepub async fn server_can_see_event(
&self,
origin: &ServerName,
room_id: &RoomId,
event_id: &EventId,
) -> bool
pub async fn server_can_see_event( &self, origin: &ServerName, room_id: &RoomId, event_id: &EventId, ) -> bool
Whether a server is allowed to see an event through federation, based on the room’s history_visibility at that event’s state.
Sourceimpl Service
impl Service
Sourcepub async fn user_was_joined(
&self,
shortstatehash: ShortStateHash,
user_id: &UserId,
) -> bool
pub async fn user_was_joined( &self, shortstatehash: ShortStateHash, user_id: &UserId, ) -> bool
The user was a joined member at this state (potentially in the past)
Sourceimpl Service
impl Service
Sourcepub async fn user_was_invited(
&self,
shortstatehash: ShortStateHash,
user_id: &UserId,
) -> bool
pub async fn user_was_invited( &self, shortstatehash: ShortStateHash, user_id: &UserId, ) -> bool
The user was an invited or joined room member at this state (potentially in the past)
Sourceimpl Service
impl Service
Sourcepub async fn user_membership(
&self,
shortstatehash: ShortStateHash,
user_id: &UserId,
) -> MembershipState
pub async fn user_membership( &self, shortstatehash: ShortStateHash, user_id: &UserId, ) -> MembershipState
Get membership for given user in state
Sourceimpl Service
impl Service
Sourcepub async fn user_membership_at_pdu(
&self,
user_id: &UserId,
pdu: &Pdu,
) -> MembershipState
pub async fn user_membership_at_pdu( &self, user_id: &UserId, pdu: &Pdu, ) -> MembershipState
MSC4115: the user’s room membership “just after” the given PDU landed.
pdu_shortstatehash returns state-before-the-event, so a member event
targeting user_id overrides that lookup with its own content.
Sourceimpl Service
impl Service
Sourcepub async fn state_get_content<T>(
&self,
shortstatehash: ShortStateHash,
event_type: &StateEventType,
state_key: &str,
) -> Result<T>where
T: for<'de> Deserialize<'de> + Send,
pub async fn state_get_content<T>(
&self,
shortstatehash: ShortStateHash,
event_type: &StateEventType,
state_key: &str,
) -> Result<T>where
T: for<'de> Deserialize<'de> + Send,
Returns a single PDU from room_id with key (event_type,state_key).
Sourceimpl Service
impl Service
pub async fn state_contains( &self, shortstatehash: ShortStateHash, event_type: &StateEventType, state_key: &str, ) -> bool
Sourceimpl Service
impl Service
pub async fn state_contains_type( &self, shortstatehash: ShortStateHash, event_type: &StateEventType, ) -> bool
Sourceimpl Service
impl Service
pub async fn state_contains_shortstatekey( &self, shortstatehash: ShortStateHash, shortstatekey: ShortStateKey, ) -> bool
Sourceimpl Service
impl Service
Sourcepub async fn state_get_id(
&self,
shortstatehash: ShortStateHash,
event_type: &StateEventType,
state_key: &str,
) -> Result<OwnedEventId>
pub async fn state_get_id( &self, shortstatehash: ShortStateHash, event_type: &StateEventType, state_key: &str, ) -> Result<OwnedEventId>
Returns a single EventId from room_id with key (event_type,
state_key).
Sourceimpl Service
impl Service
Sourcepub async fn state_get_shortid(
&self,
shortstatehash: ShortStateHash,
event_type: &StateEventType,
state_key: &str,
) -> Result<ShortEventId>
pub async fn state_get_shortid( &self, shortstatehash: ShortStateHash, event_type: &StateEventType, state_key: &str, ) -> Result<ShortEventId>
Returns a single EventId from room_id with key (event_type,
state_key).
Sourceimpl Service
impl Service
Sourcepub fn state_type_pdus<'a>(
&'a self,
shortstatehash: ShortStateHash,
event_type: &'a StateEventType,
) -> impl Stream<Item = impl Event> + Send + 'a
pub fn state_type_pdus<'a>( &'a self, shortstatehash: ShortStateHash, event_type: &'a StateEventType, ) -> impl Stream<Item = impl Event> + Send + 'a
Iterates the events for an event_type in the state.
Sourceimpl Service
impl Service
Sourcepub fn state_keys_with_ids<'a>(
&'a self,
shortstatehash: ShortStateHash,
event_type: &'a StateEventType,
) -> impl Stream<Item = (StateKey, OwnedEventId)> + Send + 'a
pub fn state_keys_with_ids<'a>( &'a self, shortstatehash: ShortStateHash, event_type: &'a StateEventType, ) -> impl Stream<Item = (StateKey, OwnedEventId)> + Send + 'a
Iterates the state_keys for an event_type in the state; current state event_id included.
Sourceimpl Service
impl Service
Sourcepub fn state_keys_with_shortids<'a>(
&'a self,
shortstatehash: ShortStateHash,
event_type: &'a StateEventType,
) -> impl Stream<Item = (StateKey, ShortEventId)> + Send + 'a
pub fn state_keys_with_shortids<'a>( &'a self, shortstatehash: ShortStateHash, event_type: &'a StateEventType, ) -> impl Stream<Item = (StateKey, ShortEventId)> + Send + 'a
Iterates the state_keys for an event_type in the state; current state event_id included.
Sourceimpl Service
impl Service
Sourcepub fn state_keys<'a>(
&'a self,
shortstatehash: ShortStateHash,
event_type: &'a StateEventType,
) -> impl Stream<Item = StateKey> + Send + 'a
pub fn state_keys<'a>( &'a self, shortstatehash: ShortStateHash, event_type: &'a StateEventType, ) -> impl Stream<Item = StateKey> + Send + 'a
Iterates the state_keys for an event_type in the state
Sourceimpl Service
impl Service
Sourcepub fn state_removed(
&self,
shortstatehash: (ShortStateHash, ShortStateHash),
) -> impl Stream<Item = (ShortStateKey, ShortEventId)> + Send + '_
pub fn state_removed( &self, shortstatehash: (ShortStateHash, ShortStateHash), ) -> impl Stream<Item = (ShortStateKey, ShortEventId)> + Send + '_
Returns the state events removed between the interval (present in .0 but not in .1)
Sourceimpl Service
impl Service
Sourcepub fn state_added(
&self,
shortstatehash: (ShortStateHash, ShortStateHash),
) -> impl Stream<Item = (ShortStateKey, ShortEventId)> + Send + '_
pub fn state_added( &self, shortstatehash: (ShortStateHash, ShortStateHash), ) -> impl Stream<Item = (ShortStateKey, ShortEventId)> + Send + '_
Returns the state events added between the interval (present in .1 but not in .0)
Sourceimpl Service
impl Service
pub fn state_full( &self, shortstatehash: ShortStateHash, ) -> impl Stream<Item = ((StateEventType, StateKey), impl Event)> + Send + '_
Sourceimpl Service
impl Service
pub fn state_full_pdus( &self, shortstatehash: ShortStateHash, ) -> impl Stream<Item = impl Event> + Send + '_
Sourceimpl Service
impl Service
Sourcepub fn state_full_ids(
&self,
shortstatehash: ShortStateHash,
) -> impl Stream<Item = (ShortStateKey, OwnedEventId)> + Send + '_
pub fn state_full_ids( &self, shortstatehash: ShortStateHash, ) -> impl Stream<Item = (ShortStateKey, OwnedEventId)> + Send + '_
Builds a StateMap by iterating over all keys that start with state_hash, this gives the full state for the given state_hash.
Sourceimpl Service
impl Service
pub fn state_full_shortids( &self, shortstatehash: ShortStateHash, ) -> impl Stream<Item = Result<(ShortStateKey, ShortEventId)>> + Send + '_
Sourceimpl Service
impl Service
async fn load_full_state( &self, shortstatehash: ShortStateHash, ) -> Result<Arc<CompressedState>>
Sourceimpl Service
impl Service
Sourcepub async fn user_can_redact(
&self,
redacts: &EventId,
sender: &UserId,
room_id: &RoomId,
federation: bool,
) -> Result<bool>
pub async fn user_can_redact( &self, redacts: &EventId, sender: &UserId, room_id: &RoomId, federation: bool, ) -> Result<bool>
Checks if a given user can redact a given event
If federation is true, it allows redaction events from any user of the same server as the original event sender
Sourceimpl Service
impl Service
Sourcepub async fn user_can_see_event(
&self,
user_id: &UserId,
room_id: &RoomId,
event_id: &EventId,
) -> bool
pub async fn user_can_see_event( &self, user_id: &UserId, room_id: &RoomId, event_id: &EventId, ) -> bool
Whether a user is allowed to see an event, based on the room’s history_visibility at that event’s state.
Sourceimpl Service
impl Service
Sourcepub async fn user_can_see_state_events(
&self,
user_id: &UserId,
room_id: &RoomId,
) -> bool
pub async fn user_can_see_state_events( &self, user_id: &UserId, room_id: &RoomId, ) -> bool
Whether a user is allowed to see an event, based on the room’s history_visibility at that event’s state.
Sourceimpl Service
impl Service
pub async fn user_can_invite( &self, room_id: &RoomId, sender: &UserId, target_user: &UserId, state_lock: &RoomMutexGuard, ) -> bool
Sourceimpl Service
impl Service
pub async fn user_can_tombstone( &self, room_id: &RoomId, user_id: &UserId, state_lock: &RoomMutexGuard, ) -> bool
Sourceimpl Service
impl Service
Sourcepub async fn get_power_levels(
&self,
room_id: &RoomId,
) -> Result<RoomPowerLevels>
pub async fn get_power_levels( &self, room_id: &RoomId, ) -> Result<RoomPowerLevels>
Gets the effective power levels of a room, regardless of if there is an
m.room.power_levels state.
pub async fn get_create(&self, room_id: &RoomId) -> Result<RoomCreateEvent<Pdu>>
pub async fn get_name(&self, room_id: &RoomId) -> Result<String>
pub async fn get_avatar( &self, room_id: &RoomId, ) -> Result<RoomAvatarEventContent>
pub async fn is_direct(&self, room_id: &RoomId, user_id: &UserId) -> bool
pub async fn get_member( &self, room_id: &RoomId, user_id: &UserId, ) -> Result<RoomMemberEventContent>
Sourcepub async fn is_world_readable(&self, room_id: &RoomId) -> bool
pub async fn is_world_readable(&self, room_id: &RoomId) -> bool
Checks if guests are able to view room content without joining
Sourcepub async fn guest_can_join(&self, room_id: &RoomId) -> bool
pub async fn guest_can_join(&self, room_id: &RoomId) -> bool
Checks if guests are able to join a given room
Sourcepub async fn get_canonical_alias(
&self,
room_id: &RoomId,
) -> Result<OwnedRoomAliasId>
pub async fn get_canonical_alias( &self, room_id: &RoomId, ) -> Result<OwnedRoomAliasId>
Gets the primary alias from canonical alias event
Sourcepub async fn get_room_topic(&self, room_id: &RoomId) -> Result<String>
pub async fn get_room_topic(&self, room_id: &RoomId) -> Result<String>
Gets the room topic
Sourcepub async fn get_join_rules(&self, room_id: &RoomId) -> JoinRule
pub async fn get_join_rules(&self, room_id: &RoomId) -> JoinRule
Returns the join rules for a given room (JoinRule type). Will default
to Invite if doesnt exist or invalid
pub async fn get_room_type(&self, room_id: &RoomId) -> Result<RoomType>
Sourcepub async fn get_room_encryption(
&self,
room_id: &RoomId,
) -> Result<EventEncryptionAlgorithm>
pub async fn get_room_encryption( &self, room_id: &RoomId, ) -> Result<EventEncryptionAlgorithm>
Gets the room’s encryption algorithm if m.room.encryption state event
is found
pub async fn is_encrypted_room(&self, room_id: &RoomId) -> bool