pub struct Service {
appservice_in_room_cache: RwLock<HashMap<OwnedRoomId, HashMap<String, bool>>>,
services: Arc<OnceServices>,
db: Data,
}Fields
appservice_in_room_cache: RwLock<HashMap<OwnedRoomId, HashMap<String, bool>>>services: Arc<OnceServices>db: DataImplementations
Sourceimpl Service
impl Service
Sourcepub async fn update_membership(
&self,
room_id: &RoomId,
user_id: &UserId,
membership_event: RoomMemberEventContent,
sender: &UserId,
last_state: Option<Vec<Raw<AnyStrippedStateEvent>>>,
invite_via: Option<Vec<OwnedServerName>>,
update_joined_count: bool,
count: PduCount,
) -> Result
pub async fn update_membership( &self, room_id: &RoomId, user_id: &UserId, membership_event: RoomMemberEventContent, sender: &UserId, last_state: Option<Vec<Raw<AnyStrippedStateEvent>>>, invite_via: Option<Vec<OwnedServerName>>, update_joined_count: bool, count: PduCount, ) -> Result
Update current membership data.
Sourceimpl Service
impl Service
pub async fn update_joined_count(&self, room_id: &RoomId)
Sourceimpl Service
impl Service
Sourcepub(crate) fn mark_as_joined(
&self,
user_id: &UserId,
room_id: &RoomId,
count: PduCount,
)
pub(crate) fn mark_as_joined( &self, user_id: &UserId, room_id: &RoomId, count: PduCount, )
Direct DB function to directly mark a user as joined. It is not
recommended to use this directly. You most likely should use
update_membership instead
Sourceimpl Service
impl Service
Sourcepub(crate) fn mark_as_left(
&self,
user_id: &UserId,
room_id: &RoomId,
count: PduCount,
)
pub(crate) fn mark_as_left( &self, user_id: &UserId, room_id: &RoomId, count: PduCount, )
Direct DB function to directly mark a user as left. It is not
recommended to use this directly. You most likely should use
update_membership instead
Sourceimpl Service
impl Service
Sourcepub(crate) fn _mark_as_knocked(
&self,
user_id: &UserId,
room_id: &RoomId,
count: PduCount,
knocked_state: Option<Vec<Raw<AnyStrippedStateEvent>>>,
)
pub(crate) fn _mark_as_knocked( &self, user_id: &UserId, room_id: &RoomId, count: PduCount, knocked_state: Option<Vec<Raw<AnyStrippedStateEvent>>>, )
Direct DB function to directly mark a user as knocked. It is not
recommended to use this directly. You most likely should use
update_membership instead
Sourceimpl Service
impl Service
fn mark_as_once_joined(&self, user_id: &UserId, room_id: &RoomId)
Sourceimpl Service
impl Service
pub async fn add_servers_invite_via( &self, room_id: &RoomId, servers: Vec<OwnedServerName>, )
Sourceimpl Service
impl Service
Sourcepub async fn servers_route_via(
&self,
room_id: &RoomId,
) -> Result<Vec<OwnedServerName>>
pub async fn servers_route_via( &self, room_id: &RoomId, ) -> Result<Vec<OwnedServerName>>
Gets up to five servers that are likely to be in the room in the distant future.
Sourceimpl Service
impl Service
pub fn servers_invite_via<'a>( &'a self, room_id: &'a RoomId, ) -> impl Stream<Item = &ServerName> + Send + 'a
Sourceimpl Service
impl Service
pub async fn appservice_in_room( &self, room_id: &RoomId, appservice: &RegistrationInfo, ) -> bool
Sourceimpl Service
impl Service
pub fn clear_appservice_in_room_cache(&self)
Sourceimpl Service
impl Service
Sourcepub fn room_servers<'a>(
&'a self,
room_id: &'a RoomId,
) -> impl Stream<Item = &ServerName> + Send + 'a
pub fn room_servers<'a>( &'a self, room_id: &'a RoomId, ) -> impl Stream<Item = &ServerName> + Send + 'a
Returns an iterator of all servers participating in this room.
Sourceimpl Service
impl Service
pub async fn server_in_room<'a>( &'a self, server: &'a ServerName, room_id: &'a RoomId, ) -> bool
Sourceimpl Service
impl Service
Sourcepub fn server_rooms<'a>(
&'a self,
server: &'a ServerName,
) -> impl Stream<Item = &RoomId> + Send + 'a
pub fn server_rooms<'a>( &'a self, server: &'a ServerName, ) -> impl Stream<Item = &RoomId> + Send + 'a
Returns an iterator of all rooms a server participates in (as far as we know).
Sourceimpl Service
impl Service
Sourcepub async fn server_sees_user(
&self,
server: &ServerName,
user_id: &UserId,
) -> bool
pub async fn server_sees_user( &self, server: &ServerName, user_id: &UserId, ) -> bool
Returns true if server can see user by sharing at least one room.
Sourceimpl Service
impl Service
Sourcepub async fn user_sees_user(&self, user_a: &UserId, user_b: &UserId) -> bool
pub async fn user_sees_user(&self, user_a: &UserId, user_b: &UserId) -> bool
Returns true if user_a and user_b share at least one room.
Sourceimpl Service
impl Service
Sourcepub fn room_members<'a>(
&'a self,
room_id: &'a RoomId,
) -> impl Stream<Item = &UserId> + Send + 'a
pub fn room_members<'a>( &'a self, room_id: &'a RoomId, ) -> impl Stream<Item = &UserId> + Send + 'a
Returns an iterator of all joined members of a room.
Sourceimpl Service
impl Service
Sourcepub async fn room_joined_count(&self, room_id: &RoomId) -> Result<u64>
pub async fn room_joined_count(&self, room_id: &RoomId) -> Result<u64>
Returns the number of users which are currently in a room
Sourceimpl Service
impl Service
Sourcepub async fn room_invited_count(&self, room_id: &RoomId) -> Result<u64>
pub async fn room_invited_count(&self, room_id: &RoomId) -> Result<u64>
Returns the number of users which are currently invited to a room
Sourceimpl Service
impl Service
Sourcepub async fn room_knocked_count(&self, room_id: &RoomId) -> Result<u64>
pub async fn room_knocked_count(&self, room_id: &RoomId) -> Result<u64>
Returns the number of users which are currently knocking upon a room
Sourceimpl Service
impl Service
Sourcepub fn active_local_users_in_room<'a>(
&'a self,
room_id: &'a RoomId,
) -> impl Stream<Item = &UserId> + Send + 'a
pub fn active_local_users_in_room<'a>( &'a self, room_id: &'a RoomId, ) -> impl Stream<Item = &UserId> + Send + 'a
Returns an iterator of all our local joined users in a room who are active (not deactivated, not guest)
Sourceimpl Service
impl Service
Sourcepub fn local_users_in_room<'a>(
&'a self,
room_id: &'a RoomId,
) -> impl Stream<Item = &UserId> + Send + 'a
pub fn local_users_in_room<'a>( &'a self, room_id: &'a RoomId, ) -> impl Stream<Item = &UserId> + Send + 'a
Returns an iterator of all our local users in the room, even if they’re deactivated/guests
Sourceimpl Service
impl Service
Sourcepub fn local_users_invited_to_room<'a>(
&'a self,
room_id: &'a RoomId,
) -> impl Stream<Item = &UserId> + Send + 'a
pub fn local_users_invited_to_room<'a>( &'a self, room_id: &'a RoomId, ) -> impl Stream<Item = &UserId> + Send + 'a
Returns an iterator of only our users invited to this room.
Sourceimpl Service
impl Service
Sourcepub fn room_useroncejoined<'a>(
&'a self,
room_id: &'a RoomId,
) -> impl Stream<Item = &UserId> + Send + 'a
pub fn room_useroncejoined<'a>( &'a self, room_id: &'a RoomId, ) -> impl Stream<Item = &UserId> + Send + 'a
Returns an iterator over all User IDs who ever joined a room.
Sourceimpl Service
impl Service
Sourcepub fn room_members_invited<'a>(
&'a self,
room_id: &'a RoomId,
) -> impl Stream<Item = &UserId> + Send + 'a
pub fn room_members_invited<'a>( &'a self, room_id: &'a RoomId, ) -> impl Stream<Item = &UserId> + Send + 'a
Returns an iterator over all invited members of a room.
Sourceimpl Service
impl Service
Sourcepub fn room_members_knocked<'a>(
&'a self,
room_id: &'a RoomId,
) -> impl Stream<Item = &UserId> + Send + 'a
pub fn room_members_knocked<'a>( &'a self, room_id: &'a RoomId, ) -> impl Stream<Item = &UserId> + Send + 'a
Returns an iterator over all knocked members of a room.
Sourceimpl Service
impl Service
pub async fn get_invite_count( &self, room_id: &RoomId, user_id: &UserId, ) -> Result<u64>
Sourceimpl Service
impl Service
pub async fn get_knock_count( &self, room_id: &RoomId, user_id: &UserId, ) -> Result<u64>
Sourceimpl Service
impl Service
pub async fn get_left_count( &self, room_id: &RoomId, user_id: &UserId, ) -> Result<u64>
Sourceimpl Service
impl Service
pub async fn get_joined_count( &self, room_id: &RoomId, user_id: &UserId, ) -> Result<u64>
Sourceimpl Service
impl Service
Sourcepub fn all_user_memberships<'a>(
&'a self,
user_id: &'a UserId,
) -> impl Stream<Item = (MembershipState, &RoomId)> + Send + 'a
pub fn all_user_memberships<'a>( &'a self, user_id: &'a UserId, ) -> impl Stream<Item = (MembershipState, &RoomId)> + Send + 'a
Returns an iterator over all memberships for a user.
Sourceimpl Service
impl Service
Sourcepub fn user_memberships<'a>(
&'a self,
user_id: &'a UserId,
mask: Option<&[MembershipState]>,
) -> impl Stream<Item = (MembershipState, &RoomId)> + Send + 'a
pub fn user_memberships<'a>( &'a self, user_id: &'a UserId, mask: Option<&[MembershipState]>, ) -> impl Stream<Item = (MembershipState, &RoomId)> + Send + 'a
Returns an iterator over all specified memberships for a user.
Sourceimpl Service
impl Service
Sourcepub fn rooms_joined<'a>(
&'a self,
user_id: &'a UserId,
) -> impl Stream<Item = &RoomId> + Send + 'a
pub fn rooms_joined<'a>( &'a self, user_id: &'a UserId, ) -> impl Stream<Item = &RoomId> + Send + 'a
Returns an iterator over all rooms this user joined.
Sourceimpl Service
impl Service
Sourcepub fn rooms_invited<'a>(
&'a self,
user_id: &'a UserId,
) -> impl Stream<Item = &RoomId> + Send + 'a
pub fn rooms_invited<'a>( &'a self, user_id: &'a UserId, ) -> impl Stream<Item = &RoomId> + Send + 'a
Returns an iterator over all rooms a user was invited to.
Sourceimpl Service
impl Service
Sourcepub fn rooms_knocked<'a>(
&'a self,
user_id: &'a UserId,
) -> impl Stream<Item = &RoomId> + Send + 'a
pub fn rooms_knocked<'a>( &'a self, user_id: &'a UserId, ) -> impl Stream<Item = &RoomId> + Send + 'a
Returns an iterator over all rooms a user is currently knocking.
Sourceimpl Service
impl Service
Sourcepub fn rooms_left<'a>(
&'a self,
user_id: &'a UserId,
) -> impl Stream<Item = &RoomId> + Send + 'a
pub fn rooms_left<'a>( &'a self, user_id: &'a UserId, ) -> impl Stream<Item = &RoomId> + Send + 'a
Returns an iterator over all rooms a user left.
Sourceimpl Service
impl Service
Sourcepub fn rooms_invited_state<'a>(
&'a self,
user_id: &'a UserId,
) -> impl Stream<Item = (OwnedRoomId, Vec<Raw<AnyStrippedStateEvent>>)> + Send + 'a
pub fn rooms_invited_state<'a>( &'a self, user_id: &'a UserId, ) -> impl Stream<Item = (OwnedRoomId, Vec<Raw<AnyStrippedStateEvent>>)> + Send + 'a
Returns an iterator over all rooms a user was invited to.
Sourceimpl Service
impl Service
Sourcepub fn rooms_knocked_state<'a>(
&'a self,
user_id: &'a UserId,
) -> impl Stream<Item = (OwnedRoomId, Vec<Raw<AnyStrippedStateEvent>>)> + Send + 'a
pub fn rooms_knocked_state<'a>( &'a self, user_id: &'a UserId, ) -> impl Stream<Item = (OwnedRoomId, Vec<Raw<AnyStrippedStateEvent>>)> + Send + 'a
Returns an iterator over all rooms a user is currently knocking.
Sourceimpl Service
impl Service
Sourcepub fn rooms_left_state<'a>(
&'a self,
user_id: &'a UserId,
) -> impl Stream<Item = (OwnedRoomId, Vec<Raw<AnySyncStateEvent>>)> + Send + 'a
pub fn rooms_left_state<'a>( &'a self, user_id: &'a UserId, ) -> impl Stream<Item = (OwnedRoomId, Vec<Raw<AnySyncStateEvent>>)> + Send + 'a
Returns an iterator over all rooms a user left.
Sourceimpl Service
impl Service
pub async fn invite_state( &self, user_id: &UserId, room_id: &RoomId, ) -> Result<Vec<Raw<AnyStrippedStateEvent>>>
Sourceimpl Service
impl Service
pub async fn knock_state( &self, user_id: &UserId, room_id: &RoomId, ) -> Result<Vec<Raw<AnyStrippedStateEvent>>>
Sourceimpl Service
impl Service
pub async fn left_state( &self, user_id: &UserId, room_id: &RoomId, ) -> Result<Vec<Raw<AnyStrippedStateEvent>>>
Sourceimpl Service
impl Service
pub async fn user_membership( &self, user_id: &UserId, room_id: &RoomId, ) -> Option<MembershipState>
Sourceimpl Service
impl Service
pub async fn once_joined(&self, user_id: &UserId, room_id: &RoomId) -> bool