pub struct Service {
pub stateinfo_cache: Mutex<LruCache<ShortStateHash, Vec<ShortStateInfo>>>,
db: Data,
services: Arc<OnceServices>,
}Fields
stateinfo_cache: Mutex<LruCache<ShortStateHash, Vec<ShortStateInfo>>>db: Dataservices: Arc<OnceServices>Implementations
Sourceimpl Service
impl Service
Sourcepub async fn load_shortstatehash_info(
&self,
shortstatehash: ShortStateHash,
) -> Result<Vec<ShortStateInfo>>
pub async fn load_shortstatehash_info( &self, shortstatehash: ShortStateHash, ) -> Result<Vec<ShortStateInfo>>
Returns a stack with info on shortstatehash, full state, added diff and removed diff for the selected shortstatehash and each parent layer.
Sourceimpl Service
impl Service
Sourceasync fn cache_shortstatehash_info(
&self,
shortstatehash: ShortStateHash,
stack: Vec<ShortStateInfo>,
) -> Result
async fn cache_shortstatehash_info( &self, shortstatehash: ShortStateHash, stack: Vec<ShortStateInfo>, ) -> Result
Returns a stack with info on shortstatehash, full state, added diff and removed diff for the selected shortstatehash and each parent layer.
Sourceimpl Service
impl Service
async fn new_shortstatehash_info( &self, shortstatehash: ShortStateHash, ) -> Result<Vec<ShortStateInfo>>
Sourceimpl Service
impl Service
pub fn compress_state_events<'a, I>( &'a self, state: I, ) -> impl Stream<Item = CompressedStateEvent> + Send + 'a
Sourceimpl Service
impl Service
pub async fn compress_state_event( &self, shortstatekey: ShortStateKey, event_id: &EventId, ) -> CompressedStateEvent
Sourceimpl Service
impl Service
Sourcepub fn save_state_from_diff(
&self,
shortstatehash: ShortStateHash,
statediffnew: Arc<CompressedState>,
statediffremoved: Arc<CompressedState>,
diff_to_sibling: usize,
parent_states: Vec<ShortStateInfo>,
) -> Result
pub fn save_state_from_diff( &self, shortstatehash: ShortStateHash, statediffnew: Arc<CompressedState>, statediffremoved: Arc<CompressedState>, diff_to_sibling: usize, parent_states: Vec<ShortStateInfo>, ) -> Result
Creates a new shortstatehash that often is just a diff to an already existing shortstatehash and therefore very efficient.
There are multiple layers of diffs. The bottom layer 0 always contains the full state. Layer 1 contains diffs to states of layer 0, layer 2 diffs to layer 1 and so on. If layer n > 0 grows too big, it will be combined with layer n-1 to create a new diff on layer n-1 that’s based on layer n-2. If that layer is also too big, it will recursively fix above layers too.
shortstatehash- Shortstatehash of this statestatediffnew- Added to base. Each vec is shortstatekey+shorteventidstatediffremoved- Removed from base. Each vec is shortstatekey+shorteventiddiff_to_sibling- Approximately how much the diff grows each time for this layerparent_states- A stack with info on shortstatehash, full state, added diff and removed diff for each parent layer
Sourceimpl Service
impl Service
Sourcepub async fn save_state(
&self,
room_id: &RoomId,
new_state_ids_compressed: Arc<CompressedState>,
) -> Result<HashSetCompressStateEvent>
pub async fn save_state( &self, room_id: &RoomId, new_state_ids_compressed: Arc<CompressedState>, ) -> Result<HashSetCompressStateEvent>
Returns the new shortstatehash, and the state diff from the previous room state
Sourceimpl Service
impl Service
async fn get_statediff( &self, shortstatehash: ShortStateHash, ) -> Result<StateDiff>
Sourceimpl Service
impl Service
fn save_statediff(&self, shortstatehash: ShortStateHash, diff: &StateDiff)