pub(super) fn auth_difference<'a, AuthSets, Id>(
auth_sets: AuthSets,
) -> impl Stream<Item = Id>Expand description
Get the auth difference for the given auth chains.
Definition in the specification:
The auth difference is calculated by first calculating the full auth chain for each state Si, that is the union of the auth chains for each event in Si, and then taking every event that doesn’t appear in every auth chain. If Ci is the full auth chain of Si, then the auth difference is ∪Ci − ∩Ci.
Arguments
auth_chains- The list of full recursive sets ofauth_events. Inputs must be sorted.
Returns
Outputs the event IDs that are not present in all the auth chains.