fn update_thread_bundle<E>(unsigned: &mut CanonicalJsonObject, event: &E)where E: Event,
Persist a latest event whose embedded sender and event ID come from the same validated event used to index the thread activity.