Service

Struct Service 

pub struct Service {
    services: Arc<OnceServices>,
    db: Data,
    pub mutex_insert: MutexMap<OwnedRoomId, ()>,
}

Fields

services: Arc<OnceServices>db: Datamutex_insert: MutexMap<OwnedRoomId, ()>

Implementations

Source

impl Service

pub(crate) async fn append_incoming_pdu<'a, Leafs>( &'a self, pdu: &'a PduEvent, pdu_json: CanonicalJsonObject, new_room_leafs: Leafs, state_ids_compressed: Arc<CompressedState>, soft_fail: bool, state_lock: &'a RoomMutexGuard, ) -> Result<Option<RawPduId>>
where Leafs: Iterator<Item = &'a EventId> + Send + 'a,

Append the incoming event setting the state snapshot to the state from the server that sent the event.

Source

impl Service

pub async fn append_pdu<'a, Leafs>( &'a self, pdu: &'a PduEvent, pdu_json: CanonicalJsonObject, leafs: Leafs, state_lock: &'a RoomMutexGuard, ) -> Result<RawPduId>
where Leafs: Iterator<Item = &'a EventId> + Send + 'a,

Creates a new persisted data unit and adds it to a room.

By this point the incoming event should be fully authenticated, no auth happens in append_pdu.

Returns pdu id

Source

impl Service

async fn append_pdu_effects( &self, pdu_id: RawPduId, pdu: &PduEvent, shortroomid: ShortRoomId, count: PduCount, state_lock: &RoomMutexGuard, ) -> Result

Source

impl Service

fn append_pdu_json( &self, pdu_id: &RawPduId, pdu: &PduEvent, json: &CanonicalJsonObject, )

Source

impl Service

pub async fn backfill_if_required( &self, room_id: &RoomId, from: PduCount, ) -> Result

Source

impl Service

pub async fn backfill_pdu( &self, room_id: &RoomId, origin: &ServerName, pdu: Box<RawJsonValue>, ) -> Result

Source

impl Service

fn prepend_backfill_pdu( &self, pdu_id: &RawPduId, room_id: &RoomId, event_id: &EventId, origin_server_ts: u64, json: &CanonicalJsonObject, )

Source

impl Service

pub async fn build_and_append_pdu( &self, pdu_builder: PduBuilder, sender: &UserId, room_id: &RoomId, state_lock: &RoomMutexGuard, ) -> Result<OwnedEventId>

Creates a new persisted data unit and adds it to a room. This function takes a roomid_mutex_state, meaning that only this function is able to mutate the room state.

Source

impl Service

async fn check_pdu_for_admin_room<Pdu>( &self, pdu: &Pdu, sender: &UserId, ) -> Result
where Pdu: Event,

Source

impl Service

async fn check_pdu_for_suspended_sender<Pdu>(&self, pdu: &Pdu) -> Result
where Pdu: Event,

MSC3823: reject PDUs from a suspended sender, except self-redaction of their own event or self-leave. Synapse only checks membership == leave and so lets suspended moderators kick others via /kick or a state PUT.

Source

impl Service

async fn is_self_redaction<Pdu>(&self, pdu: &Pdu) -> Result<bool>
where Pdu: Event,

Source

impl Service

pub async fn create_hash_and_sign_event( &self, pdu_builder: PduBuilder, sender: &UserId, room_id: &RoomId, _mutex_lock: &RoomMutexGuard, ) -> Result<(PduEvent, CanonicalJsonObject)>

Source

impl Service

pub async fn delete_pdus(&self, room_id: &RoomId) -> Result

Source

impl Service

pub fn pdus_near_ts( &self, user_id: Option<&UserId>, room_id: &RoomId, ts: MilliSecondsSinceUnixEpoch, dir: Direction, ) -> impl Stream<Item = Result<PdusIterItem>> + Send

Source

impl Service

pub fn pdu_ids_near_ts( &self, room_id: &RoomId, ts: MilliSecondsSinceUnixEpoch, dir: Direction, ) -> impl Stream<Item = Result<(MilliSecondsSinceUnixEpoch, PduId)>> + Send

Source

impl Service

pub fn all_pdus<'a>( &'a self, user_id: &'a UserId, room_id: &'a RoomId, ) -> impl Stream<Item = PdusIterItem> + Send + 'a

Returns an iterator over all PDUs in a room. Unknown rooms produce no items.

Source

impl Service

pub fn pdus<'a>( &'a self, user_id: Option<&'a UserId>, room_id: &'a RoomId, from: Option<PduCount>, ) -> impl Stream<Item = Result<PdusIterItem>> + Send + 'a

Returns an iterator over all events and their tokens in a room that happened after the event with id from in order.

Source

impl Service

pub fn pdus_rev<'a>( &'a self, user_id: Option<&'a UserId>, room_id: &'a RoomId, until: Option<PduCount>, ) -> impl Stream<Item = Result<PdusIterItem>> + Send + 'a

Returns an iterator over all events and their tokens in a room that happened before the event with id until in reverse-order.

Source

impl Service

pub fn pdus_raw(&self) -> impl Stream<Item = Result<Val<'_>>> + Send

Source

impl Service

pub fn outlier_pdus_raw(&self) -> impl Stream<Item = Result<Val<'_>>> + Send

Source

impl Service

fn each_slice( (pdu_id, pdu): KeyVal<'_>, user_id: Option<&UserId>, ) -> Result<PdusIterItem>

Source

impl Service

fn each_pdu( (pdu_id, pdu): (RawPduId, PduEvent), user_id: Option<&UserId>, ) -> Result<PdusIterItem>

Source

impl Service

pub async fn redact_pdu<Pdu: Event + Send + Sync>( &self, event_id: &EventId, reason: &Pdu, shortroomid: ShortRoomId, state_lock: &RoomMutexGuard, ) -> Result

Replace a PDU with the redacted form.

Source

impl Service

pub async fn replace_pdu( &self, pdu_id: &RawPduId, pdu_json: &CanonicalJsonObject, ) -> Result

Removes a pdu and creates a new one with the same id.

Source

impl Service

pub fn add_pdu_outlier(&self, event_id: &EventId, pdu: &CanonicalJsonObject)

Source

impl Service

pub async fn first_pdu_in_room(&self, room_id: &RoomId) -> Result<PduEvent>

Source

impl Service

pub async fn latest_pdu_in_room(&self, room_id: &RoomId) -> Result<PduEvent>

Source

impl Service

pub async fn first_item_in_room( &self, room_id: &RoomId, ) -> Result<(PduCount, PduEvent)>

Source

impl Service

pub async fn latest_item_in_room( &self, sender_user: Option<&UserId>, room_id: &RoomId, ) -> Result<PduEvent>

Source

impl Service

pub async fn prev_shortstatehash( &self, room_id: &RoomId, before: PduCount, ) -> Result<ShortStateHash>

Returns the shortstatehash of the room at the event directly preceding the exclusive before param. before does not have to be a valid count or in the room.

Source

impl Service

pub async fn next_shortstatehash( &self, room_id: &RoomId, after: PduCount, ) -> Result<ShortStateHash>

Returns the shortstatehash of the room at the event directly following the exclusive after param. after does not have to be a valid count or in the room.

Source

impl Service

pub async fn get_shortstatehash( &self, room_id: &RoomId, count: PduCount, ) -> Result<ShortStateHash>

Returns the shortstatehash of the room at the event

Source

impl Service

pub async fn prev_timeline_count(&self, before: &PduId) -> Result<PduCount>

Returns the shorteventid in the room preceding the exclusive before param. before does not have to be a valid shorteventid or in the room.

Source

impl Service

pub async fn next_timeline_count(&self, after: &PduId) -> Result<PduCount>

Returns the next shorteventid in the room after the exclusive after param. after does not have to be a valid shorteventid or in the room.

Source

impl Service

pub async fn last_timeline_count( &self, sender_user: Option<&UserId>, room_id: &RoomId, upper_bound: Option<PduCount>, ) -> Result<PduCount>

Source

impl Service

pub async fn get_event_id_near_ts( &self, room_id: &RoomId, ts: MilliSecondsSinceUnixEpoch, dir: Direction, ) -> Result<(MilliSecondsSinceUnixEpoch, OwnedEventId)>

Source

impl Service

pub async fn get_pdu_id_near_ts( &self, room_id: &RoomId, ts: MilliSecondsSinceUnixEpoch, dir: Direction, ) -> Result<(MilliSecondsSinceUnixEpoch, PduId)>

Source

impl Service

pub async fn get_pdu_near_ts( &self, _user_id: Option<&UserId>, room_id: &RoomId, ts: MilliSecondsSinceUnixEpoch, dir: Direction, ) -> Result<PdusIterItem>

Source

impl Service

async fn count_to_id( &self, room_id: &RoomId, count: PduCount, dir: Direction, ) -> Result<RawPduId>

Source

impl Service

fn pdu_count_to_id( shortroomid: ShortRoomId, count: PduCount, dir: Direction, ) -> RawPduId

Source

impl Service

pub async fn get_pdu_from_shorteventid( &self, shorteventid: ShortEventId, ) -> Result<PduEvent>

Returns the pdu from shorteventid Checks the eventid_outlierpdu Tree if not found in the timeline.

Source

impl Service

pub async fn get_pdu(&self, event_id: &EventId) -> Result<PduEvent>

Returns the pdu. Checks the eventid_outlierpdu Tree if not found in the timeline.

Source

impl Service

pub async fn get_outlier_pdu(&self, event_id: &EventId) -> Result<PduEvent>

Returns the pdu. Checks the eventid_outlierpdu Tree if not found in the timeline.

Source

impl Service

pub async fn get_non_outlier_pdu(&self, event_id: &EventId) -> Result<PduEvent>

Returns the pdu. Checks the eventid_outlierpdu Tree if not found in the timeline.

Source

impl Service

pub async fn get_pdu_from_id(&self, pdu_id: &RawPduId) -> Result<PduEvent>

Returns the pdu. This does NOT check the outliers Tree.

Source

impl Service

pub async fn get_pdu_json( &self, event_id: &EventId, ) -> Result<CanonicalJsonObject>

Returns the json of a pdu. Checks the eventid_outlierpdu Tree if not found in the timeline.

Source

impl Service

pub async fn get_outlier_pdu_json( &self, event_id: &EventId, ) -> Result<CanonicalJsonObject>

Returns the json of a pdu. Checks the eventid_outlierpdu Tree if not found in the timeline.

Source

impl Service

pub async fn get_non_outlier_pdu_json( &self, event_id: &EventId, ) -> Result<CanonicalJsonObject>

Returns the json of a pdu. Checks the eventid_outlierpdu Tree if not found in the timeline.

Source

impl Service

pub async fn get_pdu_json_from_id( &self, pdu_id: &RawPduId, ) -> Result<CanonicalJsonObject>

Returns the pdu as a BTreeMap<String, CanonicalJsonValue>. This does NOT check the outliers Tree.

Source

impl Service

pub async fn get<T>(&self, event_id: &EventId) -> Result<T>
where T: for<'de> Deserialize<'de>,

Returns the pdu into T. Checks the eventid_outlierpdu Tree if not found in the timeline.

Source

impl Service

pub async fn get_outlier<T>(&self, event_id: &EventId) -> Result<T>
where T: for<'de> Deserialize<'de>,

Returns the pdu into T. Checks the eventid_outlierpdu Tree if not found in the timeline.

Source

impl Service

pub async fn get_non_outlier<T>(&self, event_id: &EventId) -> Result<T>
where T: for<'de> Deserialize<'de>,

Returns the pdu into T. Checks the eventid_outlierpdu Tree if not found in the timeline.

Source

impl Service

pub async fn get_from_id<T>(&self, pdu_id: &RawPduId) -> Result<T>
where T: for<'de> Deserialize<'de>,

Returns the pdu into T. This does NOT check the outliers Tree.

Source

impl Service

pub async fn pdu_exists<'a>(&'a self, event_id: &'a EventId) -> bool

Checks if pdu exists Checks the eventid_outlierpdu Tree if not found in the timeline.

Source

impl Service

pub async fn non_outlier_pdu_exists(&self, event_id: &EventId) -> Result

Like get_non_outlier_pdu(), but without the expense of fetching and parsing the PduEvent

Source

impl Service

pub async fn outlier_pdu_exists(&self, event_id: &EventId) -> Result

Like get_non_outlier_pdu(), but without the expense of fetching and parsing the PduEvent

Source

impl Service

pub async fn get_pdu_count(&self, event_id: &EventId) -> Result<PduCount>

Returns the count of this pdu’s id.

Source

impl Service

pub async fn get_shorteventid_from_pdu_id( &self, pdu_id: &PduId, ) -> Result<ShortEventId>

Returns the shorteventid from the pdu_id

Source

impl Service

pub async fn get_event_id_from_pdu_id( &self, pdu_id: &PduId, ) -> Result<OwnedEventId>

Returns the event_id from the pdu_id

Source

impl Service

pub async fn get_pdu_id_from_shorteventid( &self, shorteventid: ShortEventId, ) -> Result<RawPduId>

Returns the pdu_id from the shorteventid

Source

impl Service

pub async fn get_pdu_id(&self, event_id: &EventId) -> Result<RawPduId>

Returns the pdu’s id.