fn tagged_json(tag: u8, count: u64, value: &impl Serialize) -> EduBuf
A tagged queue row value whose body is value serialized as JSON.
value
The body is written straight into the inline buffer after the prefix.