pub struct Provider {
pub name: String,
pub config: StorageProvider,
pub(crate) provider: Box<DynObjectStore>,
pub(crate) base_path: Option<Path>,
startup_check: bool,
services: Arc<OnceServices>,
}Fields
name: Stringconfig: StorageProviderprovider: Box<DynObjectStore>base_path: Option<Path>startup_check: boolservices: Arc<OnceServices>Implementations
Sourceimpl Provider
impl Provider
Sourcepub async fn put<S, T>(
&self,
path: &str,
size: Option<usize>,
input: S,
) -> Result<PutResult>
pub async fn put<S, T>( &self, path: &str, size: Option<usize>, input: S, ) -> Result<PutResult>
Put object into store from streaming input.
Recommended to know the total size of the object. If size is None,
multi-part upload may be selected even for small uploads below the
configured threshold.
Sourceimpl Provider
impl Provider
Sourceimpl Provider
impl Provider
Sourceasync fn put_single(&self, path: &str, input: PutPayload) -> Result<PutResult>
async fn put_single(&self, path: &str, input: PutPayload) -> Result<PutResult>
Put object into the store from contiguous input non-multipart upload.
Sourceimpl Provider
impl Provider
pub fn fetch_with_metadata( &self, path: &str, ) -> impl Stream<Item = Result<FetchMetaItem>> + Send
Sourceimpl Provider
impl Provider
fn prepend_base_path(&self, location: Path) -> Path
Sourceimpl Provider
impl Provider
fn strip_base_path(&self, location: Path) -> Path