Service

Struct Service 

pub struct Service {
    services: Arc<OnceServices>,
    db: Data,
}

Fields

services: Arc<OnceServices>db: Data

Implementations

Source

impl Service

pub async fn set_dehydrated_device( &self, user_id: &UserId, request: Request, ) -> Result

Creates or recreates the user’s dehydrated device.

Source

impl Service

pub(super) async fn remove_dehydrated_device( &self, user_id: &UserId, maybe_device_id: Option<&DeviceId>, ) -> Result<OwnedDeviceId>

Removes a user’s dehydrated device.

Calling this directly will remove the dehydrated data but leak the frontage device. Thus this is called by the regular device interface such that the dehydrated data will not leak instead.

If device_id is given, the user’s dehydrated device must match or this is a no-op, but an Err is still returned to indicate that. Otherwise returns the removed dehydrated device_id.

Source

impl Service

pub async fn get_dehydrated_device_id( &self, user_id: &UserId, ) -> Result<OwnedDeviceId>

Get the device_id of the user’s dehydrated device.

Source

impl Service

pub async fn get_dehydrated_device( &self, user_id: &UserId, ) -> Result<DehydratedDevice>

Get the dehydrated device private data

Source

impl Service

pub async fn create_device( &self, user_id: &UserId, device_id: Option<&DeviceId>, __arg3: (Option<&str>, Option<Duration>), refresh_token: Option<&str>, initial_device_display_name: Option<&str>, client_ip: Option<IpAddr>, ) -> Result<OwnedDeviceId>

Adds a new device to a user.

Source

impl Service

pub async fn remove_device(&self, user_id: &UserId, device_id: &DeviceId)

Removes a device from a user.

Source

impl Service

pub fn all_device_ids<'a>( &'a self, user_id: &'a UserId, ) -> impl Stream<Item = &DeviceId> + Send + 'a

Returns an iterator over all device ids of this user.

Source

impl Service

pub async fn find_from_token( &self, token: &str, ) -> Result<(OwnedUserId, OwnedDeviceId, Option<SystemTime>)>

Find out which user an access or refresh token belongs to.

Source

impl Service

pub async fn remove_tokens(&self, user_id: &UserId, device_id: &DeviceId)

Source

impl Service

pub async fn set_access_token( &self, user_id: &UserId, device_id: &DeviceId, access_token: &str, expires_in: Option<Duration>, refresh_token: Option<&str>, ) -> Result

Replaces the access token of one device.

Source

impl Service

pub async fn remove_access_token( &self, user_id: &UserId, device_id: &DeviceId, ) -> Result

Revoke the access token without deleting the device. Take care to not leave dangling devices if using this method.

Source

impl Service

pub async fn get_access_token( &self, user_id: &UserId, device_id: &DeviceId, ) -> Result<String>

Source

impl Service

pub fn generate_access_token(&self, expires: bool) -> (String, Option<Duration>)

Source

impl Service

pub async fn set_refresh_token( &self, user_id: &UserId, device_id: &DeviceId, refresh_token: &str, ) -> Result

Replaces the refresh token of one device.

Source

impl Service

async fn find_refresh_token_expires_at( &self, user_id: &UserId, device_id: &DeviceId, ) -> Option<SystemTime>

Look up the expiry stored alongside the current refresh token for this device, if one is recorded. Pre-rotation entries carry no expiry and return None.

Source

impl Service

pub async fn remove_refresh_token( &self, user_id: &UserId, device_id: &DeviceId, ) -> Result

Revoke the refresh token without deleting the device. Take care to not leave dangling devices if using this method.

Source

impl Service

pub async fn get_refresh_token( &self, user_id: &UserId, device_id: &DeviceId, ) -> Result<String>

Source

impl Service

pub fn add_to_device_event( &self, sender: &UserId, target_user_id: &UserId, target_device_id: &DeviceId, event_type: &str, content: &Value, )

Source

impl Service

pub fn get_to_device_events<'a>( &'a self, user_id: &'a UserId, device_id: &'a DeviceId, since: Option<u64>, to: Option<u64>, ) -> impl Stream<Item = (u64, Raw<AnyToDeviceEvent>)> + Send + 'a

Source

impl Service

pub async fn remove_to_device_events<Until>( &self, user_id: &UserId, device_id: &DeviceId, until: Until, )
where Until: Into<Option<u64>> + Send,

Source

impl Service

pub async fn update_device_last_seen( &self, user_id: &UserId, device_id: &DeviceId, last_seen_ip: Option<IpAddr>, last_seen_ts: Option<MilliSecondsSinceUnixEpoch>, ) -> Result

Source

impl Service

pub fn put_device_metadata( &self, user_id: &UserId, notify: bool, device: &Device, )

Source

impl Service

pub async fn get_device_metadata( &self, user_id: &UserId, device_id: &DeviceId, ) -> Result<Device>

Get device metadata.

Source

impl Service

pub async fn device_exists( &self, user_id: &UserId, device_id: &DeviceId, ) -> bool

Source

impl Service

pub async fn is_oidc_device( &self, user_id: &UserId, device_id: &DeviceId, ) -> bool

Source

impl Service

pub async fn get_oidc_device_idp( &self, user_id: &UserId, device_id: &DeviceId, ) -> Option<String>

Returns the IdP that originally authenticated this device, if known. Returns None for devices predating the idp_id field or non-OIDC devices.

Source

impl Service

pub fn mark_oidc_device( &self, user_id: &UserId, device_id: &DeviceId, idp_id: &str, )

Source

impl Service

pub fn allow_cross_signing_replacement(&self, user_id: &UserId) -> SystemTime

Allow cross-signing key replacement without UIAA for the next 10 minutes. Returns the expiry timestamp in milliseconds.

Source

impl Service

pub async fn can_replace_cross_signing_keys(&self, user_id: &UserId) -> bool

Check if the user is allowed to replace cross-signing keys without UIAA.

Source

impl Service

pub async fn get_devicelist_version(&self, user_id: &UserId) -> Result<u64>

Source

impl Service

pub fn all_devices_metadata<'a>( &'a self, user_id: &'a UserId, ) -> impl Stream<Item = Device> + Send + 'a

Source

impl Service

pub async fn add_one_time_keys<'a, Keys>( &self, user_id: &UserId, device_id: &DeviceId, keys: Keys, ) -> Result
where Keys: Iterator<Item = (&'a OneTimeKeyId, &'a Raw<OneTimeKey>)> + Send + 'a,

Source

impl Service

pub async fn add_one_time_key( &self, user_id: &UserId, device_id: &DeviceId, one_time_key_key: &KeyId<OneTimeKeyAlgorithm, OneTimeKeyName>, one_time_key_value: &Raw<OneTimeKey>, ) -> Result

Source

impl Service

pub async fn add_fallback_keys<'a, Keys>( &self, user_id: &UserId, device_id: &DeviceId, keys: Keys, ) -> Result
where Keys: Iterator<Item = (&'a OneTimeKeyId, &'a Raw<OneTimeKey>)> + Send + 'a,

Source

impl Service

pub async fn add_fallback_key( &self, user_id: &UserId, device_id: &DeviceId, one_time_key_key: &KeyId<OneTimeKeyAlgorithm, OneTimeKeyName>, one_time_key_value: &Raw<OneTimeKey>, ) -> Result

Source

impl Service

pub async fn take_fallback_key( &self, user_id: &UserId, device_id: &DeviceId, algorithm: &OneTimeKeyAlgorithm, ) -> Result<(OwnedKeyId<OneTimeKeyAlgorithm, OneTimeKeyName>, Raw<OneTimeKey>)>

Source

impl Service

pub fn unused_fallback_key_algorithms<'a>( &'a self, user_id: &'a UserId, device_id: &'a DeviceId, ) -> impl Stream<Item = OneTimeKeyAlgorithm> + Send + 'a

Source

impl Service

pub async fn last_one_time_keys_update(&self, user_id: &UserId) -> u64

Source

impl Service

pub async fn take_one_time_key( &self, user_id: &UserId, device_id: &DeviceId, key_algorithm: &OneTimeKeyAlgorithm, ) -> Result<(OwnedKeyId<OneTimeKeyAlgorithm, OneTimeKeyName>, Raw<OneTimeKey>)>

Source

impl Service

pub async fn count_one_time_keys( &self, user_id: &UserId, device_id: &DeviceId, ) -> BTreeMap<OneTimeKeyAlgorithm, UInt>

Source

impl Service

pub async fn prune_one_time_keys( &self, user_id: &UserId, device_id: &DeviceId, excess: usize, )

MSC4225: drop the excess oldest rows for this (user, device). Forward iteration over the prefix runs in count_be ascending order, so take(excess) yields the earliest-uploaded rows.

Source

impl Service

pub async fn add_device_keys( &self, user_id: &UserId, device_id: &DeviceId, device_keys: &Raw<DeviceKeys>, )

Source

impl Service

pub async fn add_cross_signing_keys( &self, user_id: &UserId, master_key: &Option<Raw<CrossSigningKey>>, self_signing_key: &Option<Raw<CrossSigningKey>>, user_signing_key: &Option<Raw<CrossSigningKey>>, notify: bool, ) -> Result

Source

impl Service

pub async fn sign_key( &self, target_id: &UserId, key_id: &str, signature: (String, String), sender_id: &UserId, ) -> Result

Source

impl Service

pub fn keys_changed<'a>( &'a self, user_id: &'a UserId, from: u64, to: Option<u64>, ) -> impl Stream<Item = &UserId> + Send + 'a

Source

impl Service

pub fn room_keys_changed<'a>( &'a self, room_id: &'a RoomId, from: u64, to: Option<u64>, ) -> impl Stream<Item = (&UserId, u64)> + Send + 'a

Source

impl Service

fn keys_changed_user_or_room<'a>( &'a self, user_or_room_id: &'a str, from: u64, to: Option<u64>, ) -> impl Stream<Item = (&UserId, u64)> + Send + 'a

Source

impl Service

pub async fn mark_device_key_update(&self, user_id: &UserId)

Source

impl Service

pub async fn get_device_keys<'a>( &'a self, user_id: &'a UserId, device_id: &DeviceId, ) -> Result<Raw<DeviceKeys>>

Source

impl Service

pub async fn get_key<F>( &self, key_id: &[u8], sender_user: Option<&UserId>, user_id: &UserId, allowed_signatures: &F, ) -> Result<Raw<CrossSigningKey>>
where F: Fn(&UserId) -> bool + Send + Sync,

Source

impl Service

pub async fn get_master_key<F>( &self, sender_user: Option<&UserId>, user_id: &UserId, allowed_signatures: &F, ) -> Result<Raw<CrossSigningKey>>
where F: Fn(&UserId) -> bool + Send + Sync,

Source

impl Service

pub async fn get_self_signing_key<F>( &self, sender_user: Option<&UserId>, user_id: &UserId, allowed_signatures: &F, ) -> Result<Raw<CrossSigningKey>>
where F: Fn(&UserId) -> bool + Send + Sync,

Source

impl Service

pub async fn get_user_signing_key( &self, user_id: &UserId, ) -> Result<Raw<CrossSigningKey>>

Source

impl Service

pub async fn search_ldap(&self, user_id: &UserId) -> Result<Vec<(String, bool)>>

Performs a LDAP search for the given user.

Returns the list of matching users, with a boolean for each result set to true if the user is an admin.

Source

impl Service

pub async fn auth_ldap(&self, user_dn: &str, password: &str) -> Result

Source

impl Service

pub async fn update_displayname( &self, user_id: &UserId, displayname: Option<&str>, rooms: &[OwnedRoomId], propagation: Propagation, )

Source

impl Service

pub fn set_displayname(&self, user_id: &UserId, displayname: Option<&str>)

Sets a new displayname or removes it if displayname is None. You still need to notify all rooms of this change.

Source

impl Service

pub async fn displayname(&self, user_id: &UserId) -> Result<String>

Returns the displayname of a user on this homeserver.

Source

impl Service

pub async fn update_avatar_url( &self, user_id: &UserId, avatar_url: Option<&MxcUri>, blurhash: Option<&str>, rooms: &[OwnedRoomId], propagation: Propagation, )

Source

impl Service

pub fn set_avatar_url(&self, user_id: &UserId, avatar_url: Option<&MxcUri>)

Sets a new avatar_url or removes it if avatar_url is None.

Source

impl Service

pub async fn avatar_url(&self, user_id: &UserId) -> Result<OwnedMxcUri>

Get the avatar_url of a user.

Source

impl Service

pub fn set_blurhash(&self, user_id: &UserId, blurhash: Option<&str>)

Sets a new avatar_url or removes it if avatar_url is None.

Source

impl Service

pub async fn blurhash(&self, user_id: &UserId) -> Result<String>

Get the blurhash of a user.

Source

impl Service

pub fn set_timezone(&self, user_id: &UserId, timezone: Option<&str>)

Sets a new timezone or removes it if timezone is None.

Source

impl Service

pub async fn timezone(&self, user_id: &UserId) -> Result<String>

Get the timezone of a user.

Source

impl Service

pub fn all_profile_keys<'a>( &'a self, user_id: &'a UserId, ) -> impl Stream<Item = (String, Raw<ProfileFieldValue>)> + 'a + Send

Gets all the user’s profile keys and values in an iterator

Source

impl Service

pub fn set_profile_key( &self, user_id: &UserId, profile_key: &str, profile_key_value: Option<&Value>, )

Sets a new profile key value, removes the key if value is None

Source

impl Service

pub async fn profile_key( &self, user_id: &UserId, profile_key: &str, ) -> Result<Raw<ProfileFieldValue>>

Gets a specific user profile key

Source

impl Service

async fn member_displayname( &self, room_id: &RoomId, user_id: &UserId, ) -> Option<String>

Current per-room displayname for the user, or None if the room has no member event for them.

Source

impl Service

async fn member_avatar_url( &self, room_id: &RoomId, user_id: &UserId, ) -> Option<OwnedMxcUri>

Current per-room avatar_url for the user, or None if the room has no member event for them.

Source

impl Service

pub async fn full_register(&self, __arg1: Register<'_>) -> Result

Fully register a local user

Returns a device id and access token for the registered user

Source

impl Service

pub async fn user_is_ignored( &self, sender_user: &UserId, recipient_user: &UserId, ) -> bool

Returns true/false based on whether the recipient/receiving user has blocked the sender

pub async fn invites_blocked(&self, user_id: &UserId) -> bool

MSC4380: m.invite_permission_config.default_action == "block".

pub async fn create( &self, user_id: &UserId, password: Option<&str>, origin: Option<&str>, ) -> Result

Create a new user account on this homeserver.

User origin is by default “password” (meaning that it will login using its user_id/password). Users with other origins (currently only “ldap” is available) have special login processes.

pub async fn deactivate_account(&self, user_id: &UserId) -> Result

Deactivate account

pub async fn exists(&self, user_id: &UserId) -> bool

Check if a user has an account on this homeserver.

pub async fn is_deactivated(&self, user_id: &UserId) -> Result<bool>

Check if account is deactivated

pub async fn is_active(&self, user_id: &UserId) -> bool

Check if account is active, infallible

pub async fn is_active_local(&self, user_id: &UserId) -> bool

Check if account is active, infallible

pub async fn is_suspended(&self, user_id: &UserId) -> bool

MSC3823: account is suspended (read-mostly mode, sessions retained).

pub async fn is_locked(&self, user_id: &UserId) -> bool

MSC3939: account is locked (401 + soft_logout, sessions retained).

pub async fn get_suspension(&self, user_id: &UserId) -> Option<Moderation>

MSC3823: forensic record for the active suspension, if any.

pub async fn get_lock(&self, user_id: &UserId) -> Option<Moderation>

MSC3939: forensic record for the active lock, if any.

pub fn set_suspended(&self, user_id: &UserId, by: &UserId)

pub fn clear_suspended(&self, user_id: &UserId)

pub fn set_locked(&self, user_id: &UserId, by: &UserId)

pub fn clear_locked(&self, user_id: &UserId)

pub async fn count(&self) -> usize

Returns the number of users registered on this server.

pub fn stream(&self) -> impl Stream<Item = &UserId> + Send

Returns an iterator over all users on this homeserver.

pub fn list_local_users(&self) -> impl Stream<Item = &UserId> + Send + '_

Returns a list of local users as list of usernames.

A user account is considered local if the length of it’s password is greater then zero.

pub async fn origin(&self, user_id: &UserId) -> Result<String>

Returns the origin of the user (password/LDAP/…).

pub async fn has_password(&self, user_id: &UserId) -> Result<bool>

Returns whether the user has a password. Disabled accounts and registrations setting a sentinel password will return false here.

pub async fn password_hash(&self, user_id: &UserId) -> Result<String>

Returns the password hash for the given user.

pub async fn set_password( &self, user_id: &UserId, password: Option<&str>, ) -> Result

Hash and set the user’s password to the Argon2 hash

pub fn create_filter( &self, user_id: &UserId, filter: &FilterDefinition, ) -> String

Creates a new sync filter. Returns the filter id.

pub async fn get_filter( &self, user_id: &UserId, filter_id: &str, ) -> Result<FilterDefinition>

pub fn create_openid_token(&self, user_id: &UserId, token: &str) -> Result<u64>

Creates an OpenID token, which can be used to prove that a user has access to an account (primarily for integrations)

pub async fn find_from_openid_token(&self, token: &str) -> Result<OwnedUserId>

Find out which user an OpenID access token belongs to.

pub fn create_login_token(&self, user_id: &UserId, token: &str) -> u64

Creates a short-lived login token, which can be used to log in using the m.login.token mechanism.

pub async fn peek_login_token(&self, token: &str) -> Result<OwnedUserId>

Verify a login token is valid and return its owner without consuming it. Unlike find_from_login_token, the token remains in the database after this call and can still be consumed later.

pub async fn find_from_login_token(&self, token: &str) -> Result<OwnedUserId>

Find out which user a login token belongs to. Removes the token to prevent double-use attacks.

async fn update_all_rooms<'a, S>(&self, user_id: &UserId, rooms: S)
where S: Stream<Item = (PduBuilder, &'a OwnedRoomId)> + Send,